@@ -22,6 +22,8 @@ var All = map[string]Group{
 			Dash{},
 			NDT{},
 		},
+		// unattendedOK is explicitly set to false, since there is no need for consumption of excessive amounts of data with background tests
+		UnattendedOK: false,
 	},
 	"middlebox": {
 		Label: "Middleboxes",
@@ -55,6 +57,8 @@ var All = map[string]Group{
 			DNSCheck{},
 			STUNReachability{},
 			TorSf{},
+			VanillaTor{},
 		},
+		UnattendedOK: true,
 	},
 }
