@@ -1,6 +1,7 @@
 package nettests
 
 import (
+	"context"
 	"database/sql"
 	"fmt"
 	"time"
@@ -13,7 +14,7 @@ import (
 	engine "github.com/ooni/probe-cli/v3/internal/engine"
 	"github.com/ooni/probe-cli/v3/internal/model"
 	"github.com/pkg/errors"
-	"upper.io/db.v3/lib/sqlbuilder"
+	"github.com/upper/db/v4"
 )
 
 // Nettest interface. Every Nettest should implement this.
@@ -55,8 +56,8 @@ type Controller struct {
 	Inputs []string
 
 	// RunType contains the run_type hint for the CheckIn API. If
-	// not set, the underlying code defaults to "timed".
-	RunType string
+	// not set, the underlying code defaults to model.RunTypeTimed.
+	RunType model.RunType
 
 	// numInputs is the total number of inputs
 	numInputs int
@@ -78,7 +79,7 @@ type Controller struct {
 //
 // Arguments:
 //
-// - db is the database in which to register the URL;
+// - sess is the database in which to register the URL;
 //
 // - testlist is the result from the check-in API (or possibly
 // a manually constructed list when applicable, e.g., for dnscheck
@@ -90,13 +91,13 @@ type Controller struct {
 //
 // - on failure, an error.
 func (c *Controller) BuildAndSetInputIdxMap(
-	db sqlbuilder.Database, testlist []model.OOAPIURLInfo) ([]string, error) {
+	sess db.Session, testlist []model.OOAPIURLInfo) ([]string, error) {
 	var urls []string
 	urlIDMap := make(map[int64]int64)
 	for idx, url := range testlist {
 		log.Debugf("Going over URL %d", idx)
 		urlID, err := database.CreateOrUpdateURL(
-			db, url.URL, url.CategoryCode, url.CountryCode,
+			sess, url.URL, url.CategoryCode, url.CountryCode,
 		)
 		if err != nil {
 			log.Error("failed to add to the URL table")
@@ -122,7 +123,7 @@ func (c *Controller) SetNettestIndex(i, n int) {
 //
 // This function will continue to run in most cases but will
 // immediately halt if something's wrong with the file system.
-func (c *Controller) Run(builder *engine.ExperimentBuilder, inputs []string) error {
+func (c *Controller) Run(builder model.ExperimentBuilder, inputs []string) error {
 	// This will configure the controller as handler for the callbacks
 	// called by ooni/probe-engine/experiment.Experiment.
 	builder.SetCallbacks(model.ExperimentCallbacks(c))
@@ -143,7 +144,7 @@ func (c *Controller) Run(builder *engine.ExperimentBuilder, inputs []string) err
 	log.Debug(color.RedString("status.started"))
 
 	if c.Probe.Config().Sharing.UploadResults {
-		if err := exp.OpenReport(); err != nil {
+		if err := exp.OpenReportContext(context.Background()); err != nil {
 			log.Debugf(
 				"%s: %s", color.RedString("failure.report_create"), err.Error(),
 			)
@@ -154,7 +155,7 @@ func (c *Controller) Run(builder *engine.ExperimentBuilder, inputs []string) err
 	}
 
 	maxRuntime := time.Duration(c.Probe.Config().Nettests.WebsitesMaxRuntime) * time.Second
-	if c.RunType == "timed" && maxRuntime > 0 {
+	if c.RunType == model.RunTypeTimed && maxRuntime > 0 {
 		log.Debug("disabling maxRuntime when running in the background")
 		maxRuntime = 0
 	}
@@ -197,7 +198,7 @@ func (c *Controller) Run(builder *engine.ExperimentBuilder, inputs []string) err
 		if input != "" {
 			c.OnProgress(0, fmt.Sprintf("processing input: %s", input))
 		}
-		measurement, err := exp.Measure(input)
+		measurement, err := exp.MeasureWithContext(context.Background(), input)
 		if err != nil {
 			log.WithError(err).Debug(color.RedString("failure.measurement"))
 			if err := c.msmts[idx64].Failed(c.Probe.DB(), err.Error()); err != nil {
@@ -218,7 +219,7 @@ func (c *Controller) Run(builder *engine.ExperimentBuilder, inputs []string) err
 			// Implementation note: SubmitMeasurement will fail here if we did fail
 			// to open the report but we still want to continue. There will be a
 			// bit of a spew in the logs, perhaps, but stopping seems less efficient.
-			if err := exp.SubmitAndUpdateMeasurement(measurement); err != nil {
+			if err := exp.SubmitAndUpdateMeasurementContext(context.Background(), measurement); err != nil {
 				log.Debug(color.RedString("failure.measurement_submission"))
 				if err := c.msmts[idx64].UploadFailed(c.Probe.DB(), err.Error()); err != nil {
 					return errors.Wrap(err, "failed to mark upload as failed")
@@ -267,7 +268,7 @@ func (c *Controller) OnProgress(perc float64, msg string) {
 	maxRuntime := time.Duration(c.Probe.Config().Nettests.WebsitesMaxRuntime) * time.Second
 	_, isWebConnectivity := c.nt.(WebConnectivity)
 	userProvidedInput := len(c.Inputs) > 0 || len(c.InputFiles) > 0
-	if c.RunType == "manual" && maxRuntime > 0 && isWebConnectivity && !userProvidedInput {
+	if c.RunType == model.RunTypeManual && maxRuntime > 0 && isWebConnectivity && !userProvidedInput {
 		elapsed := time.Since(c.ntStartTime)
 		perc = float64(elapsed) / float64(maxRuntime)
 		eta := maxRuntime.Seconds() - elapsed.Seconds()
