@@ -21,7 +21,7 @@ func TestPass(t *testing.T) {
 func TestBlock(t *testing.T) {
 	listener := newproxy(t, "ooni.io")
 	checkdialtls(t, listener.Addr().String(), false, &tls.Config{
-		ServerName: "mia-ps.ooni.io",
+		ServerName: "api.ooni.io",
 	})
 	killproxy(t, listener)
 }
@@ -94,7 +94,7 @@ func TestFailWriteAfterConnect(t *testing.T) {
 
 func TestListenError(t *testing.T) {
 	proxy := NewCensoringProxy(
-		[]string{""}, uncensored.DefaultClient,
+		[]string{""}, uncensored.NewClient("https://1.1.1.1/dns-query"),
 	)
 	listener, err := proxy.Start("8.8.8.8:80")
 	if err == nil {
@@ -107,7 +107,7 @@ func TestListenError(t *testing.T) {
 
 func newproxy(t *testing.T, blocked string) net.Listener {
 	proxy := NewCensoringProxy(
-		[]string{blocked}, uncensored.DefaultClient,
+		[]string{blocked}, uncensored.NewClient("https://1.1.1.1/dns-query"),
 	)
 	listener, err := proxy.Start("127.0.0.1:0")
 	if err != nil {
