@@ -15,10 +15,10 @@ import (
 
 	"github.com/montanaflynn/stats"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/trace"
 	"github.com/ooni/probe-cli/v3/internal/humanize"
 	"github.com/ooni/probe-cli/v3/internal/model"
 	"github.com/ooni/probe-cli/v3/internal/netxlite"
+	"github.com/ooni/probe-cli/v3/internal/tracex"
 )
 
 const (
@@ -64,7 +64,7 @@ type TestKeys struct {
 type runner struct {
 	callbacks  model.ExperimentCallbacks
 	httpClient *http.Client
-	saver      *trace.Saver
+	saver      *tracex.Saver
 	sess       model.ExperimentSession
 	tk         *TestKeys
 }
@@ -171,8 +171,8 @@ func (r runner) measure(
 		// of the latest connect time. We should have one sample in most
 		// cases, because the connection should be persistent.
 		for _, ev := range r.saver.Read() {
-			if ev.Name == netxlite.ConnectOperation {
-				connectTime = ev.Duration.Seconds()
+			if _, ok := ev.(*tracex.EventConnectOperation); ok {
+				connectTime = ev.Value().Duration.Seconds()
 			}
 		}
 		current.ConnectTime = connectTime
@@ -255,12 +255,18 @@ func (m Measurer) Run(
 ) error {
 	tk := new(TestKeys)
 	measurement.TestKeys = tk
-	saver := &trace.Saver{}
+	saver := &tracex.Saver{}
 	httpClient := &http.Client{
 		Transport: netx.NewHTTPTransport(netx.Config{
 			ContextByteCounting: true,
-			DialSaver:           saver,
-			Logger:              sess.Logger(),
+			// Implements shaping if the user builds using `-tags shaping`
+			// See https://github.com/ooni/probe/issues/2112
+			Dialer: netxlite.NewMaybeShapingDialer(netx.NewDialer(netx.Config{
+				ContextByteCounting: true,
+				Saver:               saver,
+				Logger:              sess.Logger(),
+			})),
+			Logger: sess.Logger(),
 		}),
 	}
 	defer httpClient.CloseIdleConnections()
@@ -289,7 +295,7 @@ func NewExperimentMeasurer(config Config) model.ExperimentMeasurer {
 
 // SummaryKeys contains summary keys for this experiment.
 //
-// Note that this structure is part of the ABI contract with probe-cli
+// Note that this structure is part of the ABI contract with ooniprobe
 // therefore we should be careful when changing it.
 type SummaryKeys struct {
 	Latency   float64 `json:"connect_latency"`
