@@ -1,12 +1,13 @@
 package dash
 
 import (
+	"context"
 	"io"
 	"net/http"
 	"time"
 
 	"github.com/apex/log"
-	"github.com/ooni/probe-cli/v3/internal/engine/model"
+	"github.com/ooni/probe-cli/v3/internal/model"
 )
 
 type FakeDeps struct {
@@ -36,7 +37,7 @@ func (d FakeDeps) NewHTTPRequest(
 	return d.newHTTPRequestResult, d.newHTTPRequestErr
 }
 
-func (d FakeDeps) ReadAll(r io.Reader) ([]byte, error) {
+func (d FakeDeps) ReadAllContext(ctx context.Context, r io.Reader) ([]byte, error) {
 	return d.readAllResult, d.readAllErr
 }
 
