@@ -2,10 +2,11 @@ package hhfm_test
 
 import (
 	"context"
-	"io/ioutil"
 	"net"
 	"net/http"
 	"time"
+
+	"github.com/ooni/probe-cli/v3/internal/netxlite"
 )
 
 type FakeDialer struct {
@@ -30,7 +31,7 @@ func (txp FakeTransport) RoundTrip(req *http.Request) (*http.Response, error) {
 		return txp.Func(req)
 	}
 	if req.Body != nil {
-		ioutil.ReadAll(req.Body)
+		netxlite.ReadAllContext(req.Context(), req.Body)
 		req.Body.Close()
 	}
 	if txp.Err != nil {
