@@ -12,10 +12,10 @@ import (
 	"time"
 
 	"github.com/ooni/probe-cli/v3/internal/engine/netx"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/archival"
 	"github.com/ooni/probe-cli/v3/internal/model"
 	"github.com/ooni/probe-cli/v3/internal/netxlite"
 	"github.com/ooni/probe-cli/v3/internal/randx"
+	"github.com/ooni/probe-cli/v3/internal/tracex"
 )
 
 const (
@@ -29,11 +29,11 @@ type Config struct{}
 
 // TestKeys contains the experiment test keys.
 type TestKeys struct {
-	FailureList   []*string                   `json:"failure_list"`
-	Received      []archival.MaybeBinaryValue `json:"received"`
-	Sent          []string                    `json:"sent"`
-	TamperingList []bool                      `json:"tampering_list"`
-	Tampering     bool                        `json:"tampering"`
+	FailureList   []*string                 `json:"failure_list"`
+	Received      []tracex.MaybeBinaryValue `json:"received"`
+	Sent          []string                  `json:"sent"`
+	TamperingList []bool                    `json:"tampering_list"`
+	Tampering     bool                      `json:"tampering"`
 }
 
 // NewExperimentMeasurer creates a new ExperimentMeasurer.
@@ -123,7 +123,7 @@ func (m Measurer) Run(
 			}
 			continue
 		}
-		failure := archival.NewFailure(result.Err)
+		failure := tracex.NewFailure(result.Err)
 		tk.FailureList = append(tk.FailureList, failure)
 		tk.Received = append(tk.Received, result.Received)
 		tk.Sent = append(tk.Sent, result.Sent)
@@ -131,7 +131,7 @@ func (m Measurer) Run(
 		tk.Tampering = (tk.Tampering || result.Tampering)
 		completed++
 		percentage := (float64(completed)/float64(len(m.Methods)))*0.5 + 0.5
-		callbacks.OnProgress(percentage, fmt.Sprintf("%s... %+v", result.Name, result.Err))
+		callbacks.OnProgress(percentage, fmt.Sprintf("%s... %+v", result.Name, model.ErrorToStringOrOK(result.Err)))
 		if completed >= len(m.Methods) {
 			break
 		}
@@ -150,7 +150,7 @@ type MethodConfig struct {
 type MethodResult struct {
 	Err       error
 	Name      string
-	Received  archival.MaybeBinaryValue
+	Received  tracex.MaybeBinaryValue
 	Sent      string
 	Tampering bool
 }
@@ -305,7 +305,7 @@ func RunMethod(ctx context.Context, config RunMethodConfig) {
 
 // SummaryKeys contains summary keys for this experiment.
 //
-// Note that this structure is part of the ABI contract with probe-cli
+// Note that this structure is part of the ABI contract with ooniprobe
 // therefore we should be careful when changing it.
 type SummaryKeys struct {
 	IsAnomaly bool `json:"-"`
