@@ -13,12 +13,12 @@ import (
 	"time"
 
 	"github.com/ooni/probe-cli/v3/internal/atomicx"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/archival"
 	"github.com/ooni/probe-cli/v3/internal/measurex"
 	"github.com/ooni/probe-cli/v3/internal/model"
 	"github.com/ooni/probe-cli/v3/internal/netxlite"
 	"github.com/ooni/probe-cli/v3/internal/runtimex"
 	"github.com/ooni/probe-cli/v3/internal/scrubber"
+	"github.com/ooni/probe-cli/v3/internal/tracex"
 )
 
 const (
@@ -62,11 +62,11 @@ type TargetResults struct {
 }
 
 func registerExtensions(m *model.Measurement) {
-	archival.ExtHTTP.AddTo(m)
-	archival.ExtNetevents.AddTo(m)
-	archival.ExtDNS.AddTo(m)
-	archival.ExtTCPConnect.AddTo(m)
-	archival.ExtTLSHandshake.AddTo(m)
+	tracex.ExtHTTP.AddTo(m)
+	tracex.ExtNetevents.AddTo(m)
+	tracex.ExtDNS.AddTo(m)
+	tracex.ExtTCPConnect.AddTo(m)
+	tracex.ExtTLSHandshake.AddTo(m)
 }
 
 // fillSummary fills the Summary field used by the UI.
@@ -384,7 +384,7 @@ func failureString(failure *string) (s string) {
 
 // SummaryKeys contains summary keys for this experiment.
 //
-// Note that this structure is part of the ABI contract with probe-cli
+// Note that this structure is part of the ABI contract with ooniprobe
 // therefore we should be careful when changing it.
 type SummaryKeys struct {
 	DirPortTotal            int64 `json:"dir_port_total"`
