@@ -13,11 +13,11 @@ import (
 
 	"github.com/apex/log"
 	"github.com/google/go-cmp/cmp"
-	"github.com/ooni/probe-cli/v3/internal/engine/internal/mockable"
-	"github.com/ooni/probe-cli/v3/internal/engine/legacy/oonidatamodel"
-	"github.com/ooni/probe-cli/v3/internal/engine/legacy/oonitemplates"
-	"github.com/ooni/probe-cli/v3/internal/engine/model"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/errorx"
+	"github.com/ooni/probe-cli/v3/internal/engine/mockable"
+	"github.com/ooni/probe-cli/v3/internal/measurex"
+	"github.com/ooni/probe-cli/v3/internal/model"
+	"github.com/ooni/probe-cli/v3/internal/netxlite"
+	"github.com/ooni/probe-cli/v3/internal/scrubber"
 )
 
 func TestNewExperimentMeasurer(t *testing.T) {
@@ -25,7 +25,7 @@ func TestNewExperimentMeasurer(t *testing.T) {
 	if measurer.ExperimentName() != "tor" {
 		t.Fatal("unexpected name")
 	}
-	if measurer.ExperimentVersion() != "0.3.0" {
+	if measurer.ExperimentVersion() != "0.4.0" {
 		t.Fatal("unexpected version")
 	}
 }
@@ -33,7 +33,7 @@ func TestNewExperimentMeasurer(t *testing.T) {
 func TestMeasurerMeasureFetchTorTargetsError(t *testing.T) {
 	measurer := NewMeasurer(Config{})
 	expected := errors.New("mocked error")
-	measurer.fetchTorTargets = func(ctx context.Context, sess model.ExperimentSession, cc string) (map[string]model.TorTarget, error) {
+	measurer.fetchTorTargets = func(ctx context.Context, sess model.ExperimentSession, cc string) (map[string]model.OOAPITorTarget, error) {
 		return nil, expected
 	}
 	err := measurer.Run(
@@ -51,7 +51,7 @@ func TestMeasurerMeasureFetchTorTargetsError(t *testing.T) {
 
 func TestMeasurerMeasureFetchTorTargetsEmptyList(t *testing.T) {
 	measurer := NewMeasurer(Config{})
-	measurer.fetchTorTargets = func(ctx context.Context, sess model.ExperimentSession, cc string) (map[string]model.TorTarget, error) {
+	measurer.fetchTorTargets = func(ctx context.Context, sess model.ExperimentSession, cc string) (map[string]model.OOAPITorTarget, error) {
 		return nil, nil
 	}
 	measurement := new(model.Measurement)
@@ -76,7 +76,7 @@ func TestMeasurerMeasureGoodWithMockedOrchestra(t *testing.T) {
 	// This test mocks orchestra to return a nil list of targets, so the code runs
 	// but we don't perform any actual network actions.
 	measurer := NewMeasurer(Config{})
-	measurer.fetchTorTargets = func(ctx context.Context, sess model.ExperimentSession, cc string) (map[string]model.TorTarget, error) {
+	measurer.fetchTorTargets = func(ctx context.Context, sess model.ExperimentSession, cc string) (map[string]model.OOAPITorTarget, error) {
 		return nil, nil
 	}
 	err := measurer.Run(
@@ -117,15 +117,15 @@ func TestMeasurerMeasureGood(t *testing.T) {
 	}
 }
 
-var staticPrivateTestingTargetEndpoint = "192.95.36.142:443"
+var staticPrivateTestingTargetEndpoint = "209.148.46.65:443"
 
-var staticPrivateTestingTarget = model.TorTarget{
+var staticPrivateTestingTarget = model.OOAPITorTarget{
 	Address: staticPrivateTestingTargetEndpoint,
 	Params: map[string][]string{
 		"cert": {
-			"qUVQ0srL1JI/vO6V6m/24anYXiJD3QP2HgzUKQtQ7GRqqUvs7P+tG43RtAqdhLOALP7DJQ",
+			"ssH+9rP8dG2NLDN2XuFw63hIO/9MNNinLmxQDpVa+7kTOa9/m+tGWT1SmSYpQ9uTBGa6Hw",
 		},
-		"iat-mode": {"1"},
+		"iat-mode": {"0"},
 	},
 	Protocol: "obfs4",
 	Source:   "bridgedb",
@@ -138,7 +138,7 @@ func TestMeasurerMeasureSanitiseOutput(t *testing.T) {
 	measurer := NewMeasurer(Config{})
 	sess := newsession()
 	key := "xyz-xyz-xyz-theCh2ju-ahG4chei-Ai2eka0a"
-	sess.MockableFetchTorTargetsResult = map[string]model.TorTarget{
+	sess.MockableFetchTorTargetsResult = map[string]model.OOAPITorTarget{
 		key: staticPrivateTestingTarget,
 	}
 	measurement := new(model.Measurement)
@@ -158,7 +158,7 @@ func TestMeasurerMeasureSanitiseOutput(t *testing.T) {
 	tk := measurement.TestKeys.(*TestKeys)
 	entry := tk.Targets[key]
 	if entry.Failure != nil {
-		t.Fatal("measurement failed unexpectedly")
+		t.Fatal("measurement failed unexpectedly", *entry.Failure)
 	}
 	if !bytes.Contains(data, []byte(key)) {
 		t.Fatal("cannot find expected key")
@@ -171,7 +171,7 @@ func TestMeasurerMeasureSanitiseOutput(t *testing.T) {
 	}
 }
 
-var staticTestingTargets = []model.TorTarget{
+var staticTestingTargets = []model.OOAPITorTarget{
 	{
 		Address: "192.95.36.142:443",
 		Params: map[string][]string{
@@ -225,7 +225,7 @@ func TestMeasurerMeasureTargetsCanceledContext(t *testing.T) {
 		},
 		&measurement,
 		model.NewPrinterCallbacks(log.Log),
-		map[string]model.TorTarget{
+		map[string]model.OOAPITorTarget{
 			"xx": staticTestingTargets[0],
 		},
 	)
@@ -242,7 +242,7 @@ func TestMeasurerMeasureTargetsCanceledContext(t *testing.T) {
 	}
 }
 
-func wrapTestingTarget(tt model.TorTarget) keytarget {
+func wrapTestingTarget(tt model.OOAPITorTarget) keytarget {
 	return keytarget{
 		key:    "xx", // using an super simple key; should work anyway
 		target: tt,
@@ -257,8 +257,8 @@ func TestResultsCollectorMeasureSingleTargetGood(t *testing.T) {
 		new(model.Measurement),
 		model.NewPrinterCallbacks(log.Log),
 	)
-	rc.flexibleConnect = func(context.Context, keytarget) (oonitemplates.Results, error) {
-		return oonitemplates.Results{}, nil
+	rc.flexibleConnect = func(context.Context, keytarget) (*measurex.ArchivalMeasurement, *string) {
+		return &measurex.ArchivalMeasurement{}, nil
 	}
 	rc.measureSingleTarget(
 		context.Background(), wrapTestingTarget(staticTestingTargets[0]),
@@ -291,8 +291,9 @@ func TestResultsCollectorMeasureSingleTargetWithFailure(t *testing.T) {
 		new(model.Measurement),
 		model.NewPrinterCallbacks(log.Log),
 	)
-	rc.flexibleConnect = func(context.Context, keytarget) (oonitemplates.Results, error) {
-		return oonitemplates.Results{}, errors.New("mocked error")
+	rc.flexibleConnect = func(context.Context, keytarget) (*measurex.ArchivalMeasurement, *string) {
+		failure := "mocked error"
+		return &measurex.ArchivalMeasurement{}, &failure
 	}
 	rc.measureSingleTarget(
 		context.Background(), keytarget{
@@ -330,14 +331,14 @@ func TestDefautFlexibleConnectDirPort(t *testing.T) {
 	)
 	ctx, cancel := context.WithCancel(context.Background())
 	cancel()
-	tk, err := rc.defaultFlexibleConnect(ctx, wrapTestingTarget(staticTestingTargets[1]))
-	if err == nil {
-		t.Fatal("expected an error here")
+	tk, failure := rc.defaultFlexibleConnect(ctx, wrapTestingTarget(staticTestingTargets[1]))
+	if failure == nil {
+		t.Fatal("expected a failure here")
 	}
-	if !strings.HasSuffix(err.Error(), "interrupted") {
+	if !strings.HasSuffix(*failure, "interrupted") {
 		t.Fatal("not the error we expected")
 	}
-	if tk.HTTPRequests == nil {
+	if tk.Requests == nil {
 		t.Fatal("expected HTTP data here")
 	}
 }
@@ -352,18 +353,18 @@ func TestDefautFlexibleConnectOrPort(t *testing.T) {
 	)
 	ctx, cancel := context.WithCancel(context.Background())
 	cancel()
-	tk, err := rc.defaultFlexibleConnect(ctx, wrapTestingTarget(staticTestingTargets[2]))
-	if err == nil {
-		t.Fatal("expected an error here")
+	tk, failure := rc.defaultFlexibleConnect(ctx, wrapTestingTarget(staticTestingTargets[2]))
+	if failure == nil {
+		t.Fatal("expected a failure here")
 	}
-	if err.Error() != "interrupted" {
+	if *failure != "interrupted" {
 		t.Fatal("not the error we expected")
 	}
-	if tk.Connects == nil {
+	if tk.TCPConnect == nil {
 		t.Fatal("expected connects data here")
 	}
-	if tk.NetworkEvents == nil {
-		t.Fatal("expected network events data here")
+	if tk.NetworkEvents != nil {
+		t.Fatal("expected no network events data here")
 	}
 }
 
@@ -377,18 +378,18 @@ func TestDefautFlexibleConnectOBFS4(t *testing.T) {
 	)
 	ctx, cancel := context.WithCancel(context.Background())
 	cancel()
-	tk, err := rc.defaultFlexibleConnect(ctx, wrapTestingTarget(staticTestingTargets[0]))
-	if err == nil {
-		t.Fatal("expected an error here")
+	tk, failure := rc.defaultFlexibleConnect(ctx, wrapTestingTarget(staticTestingTargets[0]))
+	if failure == nil {
+		t.Fatal("expected a failure here")
 	}
-	if err.Error() != "interrupted" {
+	if *failure != "interrupted" {
 		t.Fatal("not the error we expected")
 	}
-	if tk.Connects == nil {
+	if tk.TCPConnect == nil {
 		t.Fatal("expected connects data here")
 	}
-	if tk.NetworkEvents == nil {
-		t.Fatal("expected network events data here")
+	if tk.NetworkEvents != nil {
+		t.Fatal("expected no network events data here")
 	}
 }
 
@@ -402,24 +403,25 @@ func TestDefautFlexibleConnectDefault(t *testing.T) {
 	)
 	ctx, cancel := context.WithCancel(context.Background())
 	cancel()
-	tk, err := rc.defaultFlexibleConnect(ctx, wrapTestingTarget(staticTestingTargets[3]))
-	if err == nil {
-		t.Fatal("expected an error here")
+	tk, failure := rc.defaultFlexibleConnect(ctx, wrapTestingTarget(staticTestingTargets[3]))
+	if failure == nil {
+		t.Fatal("expected a failure here")
 	}
-	if err.Error() != "interrupted" {
-		t.Fatalf("not the error we expected: %+v", err)
+	if *failure != "interrupted" {
+		t.Fatalf("not the error we expected: %+v", *failure)
 	}
-	if tk.Connects == nil {
-		t.Fatalf("expected connects data here, found: %+v", tk.Connects)
+	if tk.TCPConnect == nil {
+		t.Fatalf("expected connects data here, found: %+v", tk.TCPConnect)
 	}
 }
 
-func TestErrString(t *testing.T) {
-	if errString(nil) != "success" {
+func TestFailureString(t *testing.T) {
+	if failureString(nil) != "success" {
 		t.Fatal("not working with nil")
 	}
-	if errString(errors.New("antani")) != "antani" {
-		t.Fatal("not working with error")
+	s := "antani"
+	if failureString(&s) != "antani" {
+		t.Fatal("not working with non-nil string")
 	}
 }
 
@@ -435,8 +437,8 @@ func TestSummary(t *testing.T) {
 	t.Run("with a TCP connect and nothing else", func(t *testing.T) {
 		tr := new(TargetResults)
 		failure := "mocked_error"
-		tr.TCPConnect = append(tr.TCPConnect, oonidatamodel.TCPConnectEntry{
-			Status: oonidatamodel.TCPConnectStatus{
+		tr.TCPConnect = append(tr.TCPConnect, &measurex.ArchivalTCPConnect{
+			Status: &measurex.ArchivalTCPConnectStatus{
 				Success: true,
 				Failure: &failure,
 			},
@@ -445,15 +447,15 @@ func TestSummary(t *testing.T) {
 		if len(tr.Summary) != 1 {
 			t.Fatal("cannot find expected entry")
 		}
-		if *tr.Summary[errorx.ConnectOperation].Failure != failure {
+		if *tr.Summary[netxlite.ConnectOperation].Failure != failure {
 			t.Fatal("invalid failure")
 		}
 	})
 
 	t.Run("for OBFS4", func(t *testing.T) {
 		tr := new(TargetResults)
-		tr.TCPConnect = append(tr.TCPConnect, oonidatamodel.TCPConnectEntry{
-			Status: oonidatamodel.TCPConnectStatus{
+		tr.TCPConnect = append(tr.TCPConnect, &measurex.ArchivalTCPConnect{
+			Status: &measurex.ArchivalTCPConnectStatus{
 				Success: true,
 			},
 		})
@@ -464,7 +466,7 @@ func TestSummary(t *testing.T) {
 		if len(tr.Summary) != 2 {
 			t.Fatal("cannot find expected entry")
 		}
-		if tr.Summary[errorx.ConnectOperation].Failure != nil {
+		if tr.Summary[netxlite.ConnectOperation].Failure != nil {
 			t.Fatal("invalid failure")
 		}
 		if *tr.Summary["handshake"].Failure != failure {
@@ -473,22 +475,22 @@ func TestSummary(t *testing.T) {
 	})
 
 	t.Run("for or_port/or_port_dirauth", func(t *testing.T) {
-		doit := func(targetProtocol string, handshake *oonidatamodel.TLSHandshake) {
+		doit := func(targetProtocol string, handshake *measurex.ArchivalQUICTLSHandshakeEvent) {
 			tr := new(TargetResults)
-			tr.TCPConnect = append(tr.TCPConnect, oonidatamodel.TCPConnectEntry{
-				Status: oonidatamodel.TCPConnectStatus{
+			tr.TCPConnect = append(tr.TCPConnect, &measurex.ArchivalTCPConnect{
+				Status: &measurex.ArchivalTCPConnectStatus{
 					Success: true,
 				},
 			})
 			tr.TargetProtocol = targetProtocol
 			if handshake != nil {
-				tr.TLSHandshakes = append(tr.TLSHandshakes, *handshake)
+				tr.TLSHandshakes = append(tr.TLSHandshakes, handshake)
 			}
 			tr.fillSummary()
 			if len(tr.Summary) < 1 {
 				t.Fatal("cannot find expected entry")
 			}
-			if tr.Summary[errorx.ConnectOperation].Failure != nil {
+			if tr.Summary[netxlite.ConnectOperation].Failure != nil {
 				t.Fatal("invalid failure")
 			}
 			if handshake == nil {
@@ -506,7 +508,7 @@ func TestSummary(t *testing.T) {
 		}
 		doit("or_port_dirauth", nil)
 		doit("or_port", nil)
-		doit("or_port", &oonidatamodel.TLSHandshake{
+		doit("or_port", &measurex.ArchivalQUICTLSHandshakeEvent{
 			Failure: (func() *string {
 				s := io.EOF.Error()
 				return &s
@@ -682,7 +684,7 @@ func TestMaybeSanitize(t *testing.T) {
 		t.Fatal(err)
 	}
 	t.Run("nothing to do", func(t *testing.T) {
-		out := maybeSanitize(input, keytarget{target: model.TorTarget{Source: ""}})
+		out := maybeSanitize(input, keytarget{target: model.OOAPITorTarget{Source: ""}})
 		diff := cmp.Diff(input, out)
 		if diff != "" {
 			t.Fatal(diff)
@@ -693,7 +695,7 @@ func TestMaybeSanitize(t *testing.T) {
 		if err := json.Unmarshal(scrubbedTargetResult, &expected); err != nil {
 			t.Fatal(err)
 		}
-		out := maybeSanitize(input, keytarget{target: model.TorTarget{
+		out := maybeSanitize(input, keytarget{target: model.OOAPITorTarget{
 			Address: "85.31.186.98:443",
 			Source:  "bridgedb",
 		}})
@@ -704,138 +706,31 @@ func TestMaybeSanitize(t *testing.T) {
 	})
 }
 
-type savingLogger struct {
-	debug []string
-	info  []string
-	warn  []string
-}
-
-func (sl *savingLogger) Debug(message string) {
-	sl.debug = append(sl.debug, message)
-}
-
-func (sl *savingLogger) Debugf(format string, v ...interface{}) {
-	sl.Debug(fmt.Sprintf(format, v...))
-}
-
-func (sl *savingLogger) Info(message string) {
-	sl.info = append(sl.info, message)
-}
-
-func (sl *savingLogger) Infof(format string, v ...interface{}) {
-	sl.Info(fmt.Sprintf(format, v...))
-}
-
-func (sl *savingLogger) Warn(message string) {
-	sl.warn = append(sl.warn, message)
-}
-
-func (sl *savingLogger) Warnf(format string, v ...interface{}) {
-	sl.Warn(fmt.Sprintf(format, v...))
-}
-
-func TestScrubLogger(t *testing.T) {
-	input := "failure: 130.192.91.211:443: no route the host"
-	expect := "failure: [scrubbed]: no route the host"
-
-	t.Run("for debug", func(t *testing.T) {
-		logger := new(savingLogger)
-		scrubber := scrubbingLogger{Logger: logger}
-		scrubber.Debug(input)
-		if len(logger.debug) != 1 && len(logger.info) != 0 && len(logger.warn) != 0 {
-			t.Fatal("unexpected number of log lines written")
-		}
-		if logger.debug[0] != expect {
-			t.Fatal("unexpected output written")
-		}
-	})
-
-	t.Run("for debugf", func(t *testing.T) {
-		logger := new(savingLogger)
-		scrubber := scrubbingLogger{Logger: logger}
-		scrubber.Debugf("%s", input)
-		if len(logger.debug) != 1 && len(logger.info) != 0 && len(logger.warn) != 0 {
-			t.Fatal("unexpected number of log lines written")
-		}
-		if logger.debug[0] != expect {
-			t.Fatal("unexpected output written")
-		}
-	})
-
-	t.Run("for info", func(t *testing.T) {
-		logger := new(savingLogger)
-		scrubber := scrubbingLogger{Logger: logger}
-		scrubber.Info(input)
-		if len(logger.debug) != 0 && len(logger.info) != 1 && len(logger.warn) != 0 {
-			t.Fatal("unexpected number of log lines written")
-		}
-		if logger.info[0] != expect {
-			t.Fatal("unexpected output written")
-		}
-	})
-
-	t.Run("for infof", func(t *testing.T) {
-		logger := new(savingLogger)
-		scrubber := scrubbingLogger{Logger: logger}
-		scrubber.Infof("%s", input)
-		if len(logger.debug) != 0 && len(logger.info) != 1 && len(logger.warn) != 0 {
-			t.Fatal("unexpected number of log lines written")
-		}
-		if logger.info[0] != expect {
-			t.Fatal("unexpected output written")
-		}
-	})
-
-	t.Run("for warn", func(t *testing.T) {
-		logger := new(savingLogger)
-		scrubber := scrubbingLogger{Logger: logger}
-		scrubber.Warn(input)
-		if len(logger.debug) != 0 && len(logger.info) != 0 && len(logger.warn) != 1 {
-			t.Fatal("unexpected number of log lines written")
-		}
-		if logger.warn[0] != expect {
-			t.Fatal("unexpected output written")
-		}
-	})
-
-	t.Run("for warnf", func(t *testing.T) {
-		logger := new(savingLogger)
-		scrubber := scrubbingLogger{Logger: logger}
-		scrubber.Warnf("%s", input)
-		if len(logger.debug) != 0 && len(logger.info) != 0 && len(logger.warn) != 1 {
-			t.Fatal("unexpected number of log lines written")
-		}
-		if logger.warn[0] != expect {
-			t.Fatal("unexpected output written")
-		}
-	})
-}
-
 func TestMaybeScrubbingLogger(t *testing.T) {
-	var input model.Logger = new(savingLogger)
+	var input model.Logger = log.Log
 
 	t.Run("for when we don't need to save", func(t *testing.T) {
-		kt := keytarget{target: model.TorTarget{
+		kt := keytarget{target: model.OOAPITorTarget{
 			Source: "",
 		}}
 		out := maybeScrubbingLogger(input, kt)
 		if out != input {
 			t.Fatal("not the output we expected")
 		}
-		if _, ok := out.(*savingLogger); !ok {
+		if _, ok := out.(*scrubber.Logger); ok {
 			t.Fatal("not the output type we expected")
 		}
 	})
 
 	t.Run("for when we need to save", func(t *testing.T) {
-		kt := keytarget{target: model.TorTarget{
+		kt := keytarget{target: model.OOAPITorTarget{
 			Source: "bridgedb",
 		}}
 		out := maybeScrubbingLogger(input, kt)
 		if out == input {
 			t.Fatal("not the output value we expected")
 		}
-		if _, ok := out.(scrubbingLogger); !ok {
+		if _, ok := out.(*scrubber.Logger); !ok {
 			t.Fatal("not the output type we expected")
 		}
 	})
@@ -902,10 +797,10 @@ func TestSummaryKeysWorksAsIntended(t *testing.T) {
 func TestTargetResultsFillSummaryDirPort(t *testing.T) {
 	tr := &TargetResults{
 		TargetProtocol: "dir_port",
-		TCPConnect: oonidatamodel.TCPConnectList{{
+		TCPConnect: []*measurex.ArchivalTCPConnect{{
 			IP:   "1.2.3.4",
 			Port: 443,
-			Status: oonidatamodel.TCPConnectStatus{
+			Status: &measurex.ArchivalTCPConnectStatus{
 				Failure: nil,
 			},
 		}},
