@@ -9,13 +9,12 @@ import (
 
 	"github.com/apex/log"
 	"github.com/ooni/probe-cli/v3/internal/engine/experiment/urlgetter"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/resolver"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/trace"
 	"github.com/ooni/probe-cli/v3/internal/netxlite"
+	"github.com/ooni/probe-cli/v3/internal/tracex"
 )
 
 func TestConfigurerNewConfigurationVanilla(t *testing.T) {
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Logger: log.Log,
 		Saver:  saver,
@@ -34,23 +33,14 @@ func TestConfigurerNewConfigurationVanilla(t *testing.T) {
 	if configuration.HTTPConfig.ContextByteCounting != true {
 		t.Fatal("not the ContextByteCounting we expected")
 	}
-	if configuration.HTTPConfig.DialSaver != saver {
-		t.Fatal("not the DialSaver we expected")
-	}
-	if configuration.HTTPConfig.HTTPSaver != saver {
-		t.Fatal("not the HTTPSaver we expected")
-	}
 	if configuration.HTTPConfig.Logger != log.Log {
 		t.Fatal("not the Logger we expected")
 	}
 	if configuration.HTTPConfig.ReadWriteSaver != saver {
 		t.Fatal("not the ReadWriteSaver we expected")
 	}
-	if configuration.HTTPConfig.ResolveSaver != saver {
-		t.Fatal("not the ResolveSaver we expected")
-	}
-	if configuration.HTTPConfig.TLSSaver != saver {
-		t.Fatal("not the TLSSaver we expected")
+	if configuration.HTTPConfig.Saver != saver {
+		t.Fatal("not the Saver we expected")
 	}
 	if configuration.HTTPConfig.BaseResolver == nil {
 		t.Fatal("not the BaseResolver we expected")
@@ -64,7 +54,7 @@ func TestConfigurerNewConfigurationVanilla(t *testing.T) {
 	if configuration.HTTPConfig.TLSConfig.NextProtos[1] != "http/1.1" {
 		t.Fatal("not the TLSConfig we expected")
 	}
-	if configuration.HTTPConfig.NoTLSVerify == true {
+	if configuration.HTTPConfig.TLSConfig.InsecureSkipVerify == true {
 		t.Fatal("not the NoTLSVerify we expected")
 	}
 	if configuration.HTTPConfig.ProxyURL != nil {
@@ -73,7 +63,7 @@ func TestConfigurerNewConfigurationVanilla(t *testing.T) {
 }
 
 func TestConfigurerNewConfigurationResolverDNSOverHTTPSPowerdns(t *testing.T) {
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Config: urlgetter.Config{
 			ResolverURL: "doh://google",
@@ -95,23 +85,14 @@ func TestConfigurerNewConfigurationResolverDNSOverHTTPSPowerdns(t *testing.T) {
 	if configuration.HTTPConfig.ContextByteCounting != true {
 		t.Fatal("not the ContextByteCounting we expected")
 	}
-	if configuration.HTTPConfig.DialSaver != saver {
-		t.Fatal("not the DialSaver we expected")
-	}
-	if configuration.HTTPConfig.HTTPSaver != saver {
-		t.Fatal("not the HTTPSaver we expected")
-	}
 	if configuration.HTTPConfig.Logger != log.Log {
 		t.Fatal("not the Logger we expected")
 	}
 	if configuration.HTTPConfig.ReadWriteSaver != saver {
 		t.Fatal("not the ReadWriteSaver we expected")
 	}
-	if configuration.HTTPConfig.ResolveSaver != saver {
-		t.Fatal("not the ResolveSaver we expected")
-	}
-	if configuration.HTTPConfig.TLSSaver != saver {
-		t.Fatal("not the TLSSaver we expected")
+	if configuration.HTTPConfig.Saver != saver {
+		t.Fatal("not the Saver we expected")
 	}
 	if configuration.HTTPConfig.BaseResolver == nil {
 		t.Fatal("not the BaseResolver we expected")
@@ -120,11 +101,11 @@ func TestConfigurerNewConfigurationResolverDNSOverHTTPSPowerdns(t *testing.T) {
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	stxp, ok := sr.Txp.(resolver.SaverDNSTransport)
+	stxp, ok := sr.Txp.(*tracex.DNSTransportSaver)
 	if !ok {
 		t.Fatal("not the DNS transport we expected")
 	}
-	dohtxp, ok := stxp.DNSTransport.(*netxlite.DNSOverHTTPS)
+	dohtxp, ok := stxp.DNSTransport.(*netxlite.DNSOverHTTPSTransport)
 	if !ok {
 		t.Fatal("not the DNS transport we expected")
 	}
@@ -140,7 +121,7 @@ func TestConfigurerNewConfigurationResolverDNSOverHTTPSPowerdns(t *testing.T) {
 	if configuration.HTTPConfig.TLSConfig.NextProtos[1] != "http/1.1" {
 		t.Fatal("not the TLSConfig we expected")
 	}
-	if configuration.HTTPConfig.NoTLSVerify == true {
+	if configuration.HTTPConfig.TLSConfig.InsecureSkipVerify == true {
 		t.Fatal("not the NoTLSVerify we expected")
 	}
 	if configuration.HTTPConfig.ProxyURL != nil {
@@ -149,7 +130,7 @@ func TestConfigurerNewConfigurationResolverDNSOverHTTPSPowerdns(t *testing.T) {
 }
 
 func TestConfigurerNewConfigurationResolverDNSOverHTTPSGoogle(t *testing.T) {
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Config: urlgetter.Config{
 			ResolverURL: "doh://google",
@@ -171,23 +152,14 @@ func TestConfigurerNewConfigurationResolverDNSOverHTTPSGoogle(t *testing.T) {
 	if configuration.HTTPConfig.ContextByteCounting != true {
 		t.Fatal("not the ContextByteCounting we expected")
 	}
-	if configuration.HTTPConfig.DialSaver != saver {
-		t.Fatal("not the DialSaver we expected")
-	}
-	if configuration.HTTPConfig.HTTPSaver != saver {
-		t.Fatal("not the HTTPSaver we expected")
-	}
 	if configuration.HTTPConfig.Logger != log.Log {
 		t.Fatal("not the Logger we expected")
 	}
 	if configuration.HTTPConfig.ReadWriteSaver != saver {
 		t.Fatal("not the ReadWriteSaver we expected")
 	}
-	if configuration.HTTPConfig.ResolveSaver != saver {
-		t.Fatal("not the ResolveSaver we expected")
-	}
-	if configuration.HTTPConfig.TLSSaver != saver {
-		t.Fatal("not the TLSSaver we expected")
+	if configuration.HTTPConfig.Saver != saver {
+		t.Fatal("not the Saver we expected")
 	}
 	if configuration.HTTPConfig.BaseResolver == nil {
 		t.Fatal("not the BaseResolver we expected")
@@ -196,11 +168,11 @@ func TestConfigurerNewConfigurationResolverDNSOverHTTPSGoogle(t *testing.T) {
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	stxp, ok := sr.Txp.(resolver.SaverDNSTransport)
+	stxp, ok := sr.Txp.(*tracex.DNSTransportSaver)
 	if !ok {
 		t.Fatal("not the DNS transport we expected")
 	}
-	dohtxp, ok := stxp.DNSTransport.(*netxlite.DNSOverHTTPS)
+	dohtxp, ok := stxp.DNSTransport.(*netxlite.DNSOverHTTPSTransport)
 	if !ok {
 		t.Fatal("not the DNS transport we expected")
 	}
@@ -216,7 +188,7 @@ func TestConfigurerNewConfigurationResolverDNSOverHTTPSGoogle(t *testing.T) {
 	if configuration.HTTPConfig.TLSConfig.NextProtos[1] != "http/1.1" {
 		t.Fatal("not the TLSConfig we expected")
 	}
-	if configuration.HTTPConfig.NoTLSVerify == true {
+	if configuration.HTTPConfig.TLSConfig.InsecureSkipVerify == true {
 		t.Fatal("not the NoTLSVerify we expected")
 	}
 	if configuration.HTTPConfig.ProxyURL != nil {
@@ -225,7 +197,7 @@ func TestConfigurerNewConfigurationResolverDNSOverHTTPSGoogle(t *testing.T) {
 }
 
 func TestConfigurerNewConfigurationResolverDNSOverHTTPSCloudflare(t *testing.T) {
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Config: urlgetter.Config{
 			ResolverURL: "doh://cloudflare",
@@ -247,23 +219,14 @@ func TestConfigurerNewConfigurationResolverDNSOverHTTPSCloudflare(t *testing.T)
 	if configuration.HTTPConfig.ContextByteCounting != true {
 		t.Fatal("not the ContextByteCounting we expected")
 	}
-	if configuration.HTTPConfig.DialSaver != saver {
-		t.Fatal("not the DialSaver we expected")
-	}
-	if configuration.HTTPConfig.HTTPSaver != saver {
-		t.Fatal("not the HTTPSaver we expected")
-	}
 	if configuration.HTTPConfig.Logger != log.Log {
 		t.Fatal("not the Logger we expected")
 	}
 	if configuration.HTTPConfig.ReadWriteSaver != saver {
 		t.Fatal("not the ReadWriteSaver we expected")
 	}
-	if configuration.HTTPConfig.ResolveSaver != saver {
-		t.Fatal("not the ResolveSaver we expected")
-	}
-	if configuration.HTTPConfig.TLSSaver != saver {
-		t.Fatal("not the TLSSaver we expected")
+	if configuration.HTTPConfig.Saver != saver {
+		t.Fatal("not the Saver we expected")
 	}
 	if configuration.HTTPConfig.BaseResolver == nil {
 		t.Fatal("not the BaseResolver we expected")
@@ -272,11 +235,11 @@ func TestConfigurerNewConfigurationResolverDNSOverHTTPSCloudflare(t *testing.T)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	stxp, ok := sr.Txp.(resolver.SaverDNSTransport)
+	stxp, ok := sr.Txp.(*tracex.DNSTransportSaver)
 	if !ok {
 		t.Fatal("not the DNS transport we expected")
 	}
-	dohtxp, ok := stxp.DNSTransport.(*netxlite.DNSOverHTTPS)
+	dohtxp, ok := stxp.DNSTransport.(*netxlite.DNSOverHTTPSTransport)
 	if !ok {
 		t.Fatal("not the DNS transport we expected")
 	}
@@ -292,7 +255,7 @@ func TestConfigurerNewConfigurationResolverDNSOverHTTPSCloudflare(t *testing.T)
 	if configuration.HTTPConfig.TLSConfig.NextProtos[1] != "http/1.1" {
 		t.Fatal("not the TLSConfig we expected")
 	}
-	if configuration.HTTPConfig.NoTLSVerify == true {
+	if configuration.HTTPConfig.TLSConfig.InsecureSkipVerify == true {
 		t.Fatal("not the NoTLSVerify we expected")
 	}
 	if configuration.HTTPConfig.ProxyURL != nil {
@@ -301,7 +264,7 @@ func TestConfigurerNewConfigurationResolverDNSOverHTTPSCloudflare(t *testing.T)
 }
 
 func TestConfigurerNewConfigurationResolverUDP(t *testing.T) {
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Config: urlgetter.Config{
 			ResolverURL: "udp://8.8.8.8:53",
@@ -323,23 +286,14 @@ func TestConfigurerNewConfigurationResolverUDP(t *testing.T) {
 	if configuration.HTTPConfig.ContextByteCounting != true {
 		t.Fatal("not the ContextByteCounting we expected")
 	}
-	if configuration.HTTPConfig.DialSaver != saver {
-		t.Fatal("not the DialSaver we expected")
-	}
-	if configuration.HTTPConfig.HTTPSaver != saver {
-		t.Fatal("not the HTTPSaver we expected")
-	}
 	if configuration.HTTPConfig.Logger != log.Log {
 		t.Fatal("not the Logger we expected")
 	}
 	if configuration.HTTPConfig.ReadWriteSaver != saver {
 		t.Fatal("not the ReadWriteSaver we expected")
 	}
-	if configuration.HTTPConfig.ResolveSaver != saver {
-		t.Fatal("not the ResolveSaver we expected")
-	}
-	if configuration.HTTPConfig.TLSSaver != saver {
-		t.Fatal("not the TLSSaver we expected")
+	if configuration.HTTPConfig.Saver != saver {
+		t.Fatal("not the Saver we expected")
 	}
 	if configuration.HTTPConfig.BaseResolver == nil {
 		t.Fatal("not the BaseResolver we expected")
@@ -348,11 +302,11 @@ func TestConfigurerNewConfigurationResolverUDP(t *testing.T) {
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	stxp, ok := sr.Txp.(resolver.SaverDNSTransport)
+	stxp, ok := sr.Txp.(*tracex.DNSTransportSaver)
 	if !ok {
 		t.Fatal("not the DNS transport we expected")
 	}
-	udptxp, ok := stxp.DNSTransport.(*netxlite.DNSOverUDP)
+	udptxp, ok := stxp.DNSTransport.(*netxlite.DNSOverUDPTransport)
 	if !ok {
 		t.Fatal("not the DNS transport we expected")
 	}
@@ -368,7 +322,7 @@ func TestConfigurerNewConfigurationResolverUDP(t *testing.T) {
 	if configuration.HTTPConfig.TLSConfig.NextProtos[1] != "http/1.1" {
 		t.Fatal("not the TLSConfig we expected")
 	}
-	if configuration.HTTPConfig.NoTLSVerify == true {
+	if configuration.HTTPConfig.TLSConfig.InsecureSkipVerify == true {
 		t.Fatal("not the NoTLSVerify we expected")
 	}
 	if configuration.HTTPConfig.ProxyURL != nil {
@@ -377,7 +331,7 @@ func TestConfigurerNewConfigurationResolverUDP(t *testing.T) {
 }
 
 func TestConfigurerNewConfigurationDNSCacheInvalidString(t *testing.T) {
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Config: urlgetter.Config{
 			DNSCache: "a",
@@ -392,7 +346,7 @@ func TestConfigurerNewConfigurationDNSCacheInvalidString(t *testing.T) {
 }
 
 func TestConfigurerNewConfigurationDNSCacheNotDomain(t *testing.T) {
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Config: urlgetter.Config{
 			DNSCache: "b b",
@@ -407,7 +361,7 @@ func TestConfigurerNewConfigurationDNSCacheNotDomain(t *testing.T) {
 }
 
 func TestConfigurerNewConfigurationDNSCacheNotIP(t *testing.T) {
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Config: urlgetter.Config{
 			DNSCache: "x.org b",
@@ -422,7 +376,7 @@ func TestConfigurerNewConfigurationDNSCacheNotIP(t *testing.T) {
 }
 
 func TestConfigurerNewConfigurationDNSCacheGood(t *testing.T) {
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Config: urlgetter.Config{
 			DNSCache: "dns.google.com 8.8.8.8 8.8.4.4",
@@ -449,7 +403,7 @@ func TestConfigurerNewConfigurationDNSCacheGood(t *testing.T) {
 }
 
 func TestConfigurerNewConfigurationResolverInvalidURL(t *testing.T) {
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Config: urlgetter.Config{
 			ResolverURL: "\t",
@@ -464,7 +418,7 @@ func TestConfigurerNewConfigurationResolverInvalidURL(t *testing.T) {
 }
 
 func TestConfigurerNewConfigurationResolverInvalidURLScheme(t *testing.T) {
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Config: urlgetter.Config{
 			ResolverURL: "antani://8.8.8.8:53",
@@ -479,7 +433,7 @@ func TestConfigurerNewConfigurationResolverInvalidURLScheme(t *testing.T) {
 }
 
 func TestConfigurerNewConfigurationTLSServerName(t *testing.T) {
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Config: urlgetter.Config{
 			TLSServerName: "www.x.org",
@@ -506,7 +460,7 @@ func TestConfigurerNewConfigurationTLSServerName(t *testing.T) {
 }
 
 func TestConfigurerNewConfigurationNoTLSVerify(t *testing.T) {
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Config: urlgetter.Config{
 			NoTLSVerify: true,
@@ -518,13 +472,13 @@ func TestConfigurerNewConfigurationNoTLSVerify(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	if configuration.HTTPConfig.NoTLSVerify != true {
+	if configuration.HTTPConfig.TLSConfig.InsecureSkipVerify != true {
 		t.Fatal("not the NoTLSVerify we expected")
 	}
 }
 
 func TestConfigurerNewConfigurationTLSv1(t *testing.T) {
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Config: urlgetter.Config{
 			TLSVersion: "TLSv1",
@@ -554,7 +508,7 @@ func TestConfigurerNewConfigurationTLSv1(t *testing.T) {
 }
 
 func TestConfigurerNewConfigurationTLSv1dot0(t *testing.T) {
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Config: urlgetter.Config{
 			TLSVersion: "TLSv1.0",
@@ -584,7 +538,7 @@ func TestConfigurerNewConfigurationTLSv1dot0(t *testing.T) {
 }
 
 func TestConfigurerNewConfigurationTLSv1dot1(t *testing.T) {
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Config: urlgetter.Config{
 			TLSVersion: "TLSv1.1",
@@ -614,7 +568,7 @@ func TestConfigurerNewConfigurationTLSv1dot1(t *testing.T) {
 }
 
 func TestConfigurerNewConfigurationTLSv1dot2(t *testing.T) {
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Config: urlgetter.Config{
 			TLSVersion: "TLSv1.2",
@@ -644,7 +598,7 @@ func TestConfigurerNewConfigurationTLSv1dot2(t *testing.T) {
 }
 
 func TestConfigurerNewConfigurationTLSv1dot3(t *testing.T) {
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Config: urlgetter.Config{
 			TLSVersion: "TLSv1.3",
@@ -674,7 +628,7 @@ func TestConfigurerNewConfigurationTLSv1dot3(t *testing.T) {
 }
 
 func TestConfigurerNewConfigurationTLSvDefault(t *testing.T) {
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Config: urlgetter.Config{},
 		Logger: log.Log,
@@ -702,7 +656,7 @@ func TestConfigurerNewConfigurationTLSvDefault(t *testing.T) {
 }
 
 func TestConfigurerNewConfigurationTLSvInvalid(t *testing.T) {
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Config: urlgetter.Config{
 			TLSVersion: "SSLv3",
@@ -718,7 +672,7 @@ func TestConfigurerNewConfigurationTLSvInvalid(t *testing.T) {
 
 func TestConfigurerNewConfigurationProxyURL(t *testing.T) {
 	URL, _ := url.Parse("socks5://127.0.0.1:9050")
-	saver := new(trace.Saver)
+	saver := new(tracex.Saver)
 	configurer := urlgetter.Configurer{
 		Logger:   log.Log,
 		Saver:    saver,
