@@ -4,6 +4,7 @@ import (
 	"context"
 	"errors"
 	"net/http"
+	"runtime"
 	"strings"
 	"testing"
 
@@ -37,18 +38,15 @@ func TestGetterWithVeryShortTimeout(t *testing.T) {
 	if tk.Failure == nil || *tk.Failure != "generic_timeout_error" {
 		t.Fatal("not the Failure we expected")
 	}
-	if len(tk.NetworkEvents) != 3 {
+	if len(tk.NetworkEvents) != 2 {
 		t.Fatal("not the NetworkEvents we expected")
 	}
 	if tk.NetworkEvents[0].Operation != "http_transaction_start" {
 		t.Fatal("not the NetworkEvents[0].Operation we expected")
 	}
-	if tk.NetworkEvents[1].Operation != "http_request_metadata" {
+	if tk.NetworkEvents[1].Operation != "http_transaction_done" {
 		t.Fatal("not the NetworkEvents[1].Operation we expected")
 	}
-	if tk.NetworkEvents[2].Operation != "http_transaction_done" {
-		t.Fatal("not the NetworkEvents[2].Operation we expected")
-	}
 	if len(tk.Queries) != 0 {
 		t.Fatal("not the Queries we expected")
 	}
@@ -104,18 +102,15 @@ func TestGetterWithCancelledContextVanilla(t *testing.T) {
 	if tk.Failure == nil || !strings.HasSuffix(*tk.Failure, "interrupted") {
 		t.Fatal("not the Failure we expected")
 	}
-	if len(tk.NetworkEvents) != 3 {
+	if len(tk.NetworkEvents) != 2 {
 		t.Fatal("not the NetworkEvents we expected")
 	}
 	if tk.NetworkEvents[0].Operation != "http_transaction_start" {
 		t.Fatal("not the NetworkEvents[0].Operation we expected")
 	}
-	if tk.NetworkEvents[1].Operation != "http_request_metadata" {
+	if tk.NetworkEvents[1].Operation != "http_transaction_done" {
 		t.Fatal("not the NetworkEvents[1].Operation we expected")
 	}
-	if tk.NetworkEvents[2].Operation != "http_transaction_done" {
-		t.Fatal("not the NetworkEvents[2].Operation we expected")
-	}
 	if len(tk.Queries) != 0 {
 		t.Fatal("not the Queries we expected")
 	}
@@ -172,18 +167,15 @@ func TestGetterWithCancelledContextAndMethod(t *testing.T) {
 	if tk.Failure == nil || !strings.HasSuffix(*tk.Failure, "interrupted") {
 		t.Fatal("not the Failure we expected")
 	}
-	if len(tk.NetworkEvents) != 3 {
+	if len(tk.NetworkEvents) != 2 {
 		t.Fatal("not the NetworkEvents we expected")
 	}
 	if tk.NetworkEvents[0].Operation != "http_transaction_start" {
 		t.Fatal("not the NetworkEvents[0].Operation we expected")
 	}
-	if tk.NetworkEvents[1].Operation != "http_request_metadata" {
+	if tk.NetworkEvents[1].Operation != "http_transaction_done" {
 		t.Fatal("not the NetworkEvents[1].Operation we expected")
 	}
-	if tk.NetworkEvents[2].Operation != "http_transaction_done" {
-		t.Fatal("not the NetworkEvents[2].Operation we expected")
-	}
 	if len(tk.Queries) != 0 {
 		t.Fatal("not the Queries we expected")
 	}
@@ -242,16 +234,13 @@ func TestGetterWithCancelledContextNoFollowRedirects(t *testing.T) {
 	if tk.Failure == nil || !strings.HasSuffix(*tk.Failure, "interrupted") {
 		t.Fatal("not the Failure we expected")
 	}
-	if len(tk.NetworkEvents) != 3 {
+	if len(tk.NetworkEvents) != 2 {
 		t.Fatal("not the NetworkEvents we expected")
 	}
 	if tk.NetworkEvents[0].Operation != "http_transaction_start" {
 		t.Fatal("not the NetworkEvents[0].Operation we expected")
 	}
-	if tk.NetworkEvents[1].Operation != "http_request_metadata" {
-		t.Fatal("not the NetworkEvents[1].Operation we expected")
-	}
-	if tk.NetworkEvents[2].Operation != "http_transaction_done" {
+	if tk.NetworkEvents[1].Operation != "http_transaction_done" {
 		t.Fatal("not the NetworkEvents[2].Operation we expected")
 	}
 	if len(tk.Queries) != 0 {
@@ -287,6 +276,9 @@ func TestGetterWithCancelledContextNoFollowRedirects(t *testing.T) {
 }
 
 func TestGetterWithCancelledContextCannotStartTunnel(t *testing.T) {
+	if strings.HasPrefix(runtime.Version(), "go1.19") {
+		t.Skip("TODO(https://github.com/ooni/probe/issues/2222)")
+	}
 	ctx, cancel := context.WithCancel(context.Background())
 	cancel() // fail immediately
 	g := urlgetter.Getter{
@@ -422,23 +414,18 @@ func TestGetterIntegrationHTTPS(t *testing.T) {
 		t.Fatal("not the Failure we expected")
 	}
 	var (
-		httpTransactionStart     bool
-		httpRequestMetadata      bool
-		resolveStart             bool
-		resolveDone              bool
-		connect                  bool
-		tlsHandshakeStart        bool
-		tlsHandshakeDone         bool
-		httpResponseMetadata     bool
-		httpResponseBodySnapshot bool
-		httpTransactionDone      bool
+		httpTransactionStart bool
+		resolveStart         bool
+		resolveDone          bool
+		connect              bool
+		tlsHandshakeStart    bool
+		tlsHandshakeDone     bool
+		httpTransactionDone  bool
 	)
 	for _, ev := range tk.NetworkEvents {
 		switch ev.Operation {
 		case "http_transaction_start":
 			httpTransactionStart = true
-		case "http_request_metadata":
-			httpRequestMetadata = true
 		case "resolve_start":
 			resolveStart = true
 		case "resolve_done":
@@ -449,24 +436,17 @@ func TestGetterIntegrationHTTPS(t *testing.T) {
 			tlsHandshakeStart = true
 		case "tls_handshake_done":
 			tlsHandshakeDone = true
-		case "http_response_metadata":
-			httpResponseMetadata = true
-		case "http_response_body_snapshot":
-			httpResponseBodySnapshot = true
 		case "http_transaction_done":
 			httpTransactionDone = true
 		}
 	}
 	ok := true
 	ok = ok && httpTransactionStart
-	ok = ok && httpRequestMetadata
 	ok = ok && resolveStart
 	ok = ok && resolveDone
 	ok = ok && connect
 	ok = ok && tlsHandshakeStart
 	ok = ok && tlsHandshakeDone
-	ok = ok && httpResponseMetadata
-	ok = ok && httpResponseBodySnapshot
 	ok = ok && httpTransactionDone
 	if !ok {
 		t.Fatal("not the NetworkEvents we expected")
@@ -657,23 +637,18 @@ func TestGetterHTTPSWithTunnel(t *testing.T) {
 		t.Fatal("not the Failure we expected")
 	}
 	var (
-		httpTransactionStart     bool
-		httpRequestMetadata      bool
-		resolveStart             bool
-		resolveDone              bool
-		connect                  bool
-		tlsHandshakeStart        bool
-		tlsHandshakeDone         bool
-		httpResponseMetadata     bool
-		httpResponseBodySnapshot bool
-		httpTransactionDone      bool
+		httpTransactionStart bool
+		resolveStart         bool
+		resolveDone          bool
+		connect              bool
+		tlsHandshakeStart    bool
+		tlsHandshakeDone     bool
+		httpTransactionDone  bool
 	)
 	for _, ev := range tk.NetworkEvents {
 		switch ev.Operation {
 		case "http_transaction_start":
 			httpTransactionStart = true
-		case "http_request_metadata":
-			httpRequestMetadata = true
 		case "resolve_start":
 			resolveStart = true
 		case "resolve_done":
@@ -684,24 +659,17 @@ func TestGetterHTTPSWithTunnel(t *testing.T) {
 			tlsHandshakeStart = true
 		case "tls_handshake_done":
 			tlsHandshakeDone = true
-		case "http_response_metadata":
-			httpResponseMetadata = true
-		case "http_response_body_snapshot":
-			httpResponseBodySnapshot = true
 		case "http_transaction_done":
 			httpTransactionDone = true
 		}
 	}
 	ok := true
 	ok = ok && httpTransactionStart
-	ok = ok && httpRequestMetadata
 	ok = ok && resolveStart == false
 	ok = ok && resolveDone == false
 	ok = ok && connect
 	ok = ok && tlsHandshakeStart
 	ok = ok && tlsHandshakeDone
-	ok = ok && httpResponseMetadata
-	ok = ok && httpResponseBodySnapshot
 	ok = ok && httpTransactionDone
 	if !ok {
 		t.Fatalf("not the NetworkEvents we expected: %+v", tk.NetworkEvents)
