@@ -4,6 +4,7 @@ import (
 	"net"
 	"net/url"
 
+	"github.com/ooni/probe-cli/v3/internal/model"
 	"github.com/ooni/probe-cli/v3/internal/netxlite"
 )
 
@@ -14,7 +15,7 @@ type DNSAnalysisResult struct {
 }
 
 // DNSNameError is the error returned by the control on NXDOMAIN
-const DNSNameError = "dns_name_error"
+const DNSNameError = model.THDNSNameError
 
 var (
 	// DNSConsistent indicates that the measurement and the
@@ -44,7 +45,13 @@ func DNSAnalysis(URL *url.URL, measurement DNSLookupResult,
 		switch *control.DNS.Failure {
 		case DNSNameError: // the control returns this on NXDOMAIN error
 			switch *measurement.Failure {
-			case netxlite.FailureDNSNXDOMAINError:
+			// When the Android getaddrinfo cache says "no data" (meaning basically
+			// "I don't know, mate") _and_ the test helper says NXDOMAIN, we can
+			// be ~confident that there's also NXDOMAIN on the Android side.
+			//
+			// See also https://github.com/ooni/probe/issues/2029.
+			case netxlite.FailureDNSNXDOMAINError,
+				netxlite.FailureAndroidDNSCacheNoData:
 				out.DNSConsistency = &DNSConsistent
 			}
 		}
