@@ -6,8 +6,8 @@ import (
 
 	"github.com/google/go-cmp/cmp"
 	"github.com/ooni/probe-cli/v3/internal/engine/experiment/webconnectivity"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/archival"
 	"github.com/ooni/probe-cli/v3/internal/netxlite"
+	"github.com/ooni/probe-cli/v3/internal/tracex"
 )
 
 func TestSummarize(t *testing.T) {
@@ -26,6 +26,7 @@ func TestSummarize(t *testing.T) {
 		probeSSLInvalidHost    = netxlite.FailureSSLInvalidHostname
 		probeSSLInvalidCert    = netxlite.FailureSSLInvalidCertificate
 		probeSSLUnknownAuth    = netxlite.FailureSSLUnknownAuthority
+		probeAndroidEaiNoData  = netxlite.FailureAndroidDNSCacheNoData
 		tcpIP                  = "tcp_ip"
 		trueValue              = true
 	)
@@ -40,8 +41,8 @@ func TestSummarize(t *testing.T) {
 		name: "with an HTTPS request with no failure",
 		args: args{
 			tk: &webconnectivity.TestKeys{
-				Requests: []archival.RequestEntry{{
-					Request: archival.HTTPRequest{
+				Requests: []tracex.RequestEntry{{
+					Request: tracex.HTTPRequest{
 						URL: "https://www.kernel.org/",
 					},
 					Failure: nil,
@@ -68,7 +69,7 @@ func TestSummarize(t *testing.T) {
 			Status:         webconnectivity.StatusAnomalyControlUnreachable,
 		},
 	}, {
-		name: "with non-existing website",
+		name: "with non-existing website (NXDOMAIN case)",
 		args: args{
 			tk: &webconnectivity.TestKeys{
 				DNSExperimentFailure: &probeNXDOMAIN,
@@ -84,6 +85,23 @@ func TestSummarize(t *testing.T) {
 			Status: webconnectivity.StatusSuccessNXDOMAIN |
 				webconnectivity.StatusExperimentDNS,
 		},
+	}, {
+		name: "with non-existing website (Android EAI_NODATA case)",
+		args: args{
+			tk: &webconnectivity.TestKeys{
+				DNSExperimentFailure: &probeAndroidEaiNoData,
+				DNSAnalysisResult: webconnectivity.DNSAnalysisResult{
+					DNSConsistency: &webconnectivity.DNSConsistent,
+				},
+			},
+		},
+		wantOut: webconnectivity.Summary{
+			BlockingReason: nil,
+			Blocking:       false,
+			Accessible:     &trueValue,
+			Status: webconnectivity.StatusSuccessNXDOMAIN |
+				webconnectivity.StatusExperimentDNS,
+		},
 	}, {
 		name: "with NXDOMAIN measured only by the probe",
 		args: args{
@@ -192,7 +210,7 @@ func TestSummarize(t *testing.T) {
 		name: "with connection refused",
 		args: args{
 			tk: &webconnectivity.TestKeys{
-				Requests: []archival.RequestEntry{{
+				Requests: []tracex.RequestEntry{{
 					Failure: &probeConnectionRefused,
 				}},
 			},
@@ -208,7 +226,7 @@ func TestSummarize(t *testing.T) {
 		name: "with connection reset",
 		args: args{
 			tk: &webconnectivity.TestKeys{
-				Requests: []archival.RequestEntry{{
+				Requests: []tracex.RequestEntry{{
 					Failure: &probeConnectionReset,
 				}},
 			},
@@ -224,7 +242,7 @@ func TestSummarize(t *testing.T) {
 		name: "with NXDOMAIN",
 		args: args{
 			tk: &webconnectivity.TestKeys{
-				Requests: []archival.RequestEntry{{
+				Requests: []tracex.RequestEntry{{
 					Failure: &probeNXDOMAIN,
 				}},
 			},
@@ -240,7 +258,7 @@ func TestSummarize(t *testing.T) {
 		name: "with EOF",
 		args: args{
 			tk: &webconnectivity.TestKeys{
-				Requests: []archival.RequestEntry{{
+				Requests: []tracex.RequestEntry{{
 					Failure: &probeEOFError,
 				}},
 			},
@@ -256,7 +274,7 @@ func TestSummarize(t *testing.T) {
 		name: "with timeout",
 		args: args{
 			tk: &webconnectivity.TestKeys{
-				Requests: []archival.RequestEntry{{
+				Requests: []tracex.RequestEntry{{
 					Failure: &probeTimeout,
 				}},
 			},
@@ -272,7 +290,7 @@ func TestSummarize(t *testing.T) {
 		name: "with SSL invalid hostname",
 		args: args{
 			tk: &webconnectivity.TestKeys{
-				Requests: []archival.RequestEntry{{
+				Requests: []tracex.RequestEntry{{
 					Failure: &probeSSLInvalidHost,
 				}},
 			},
@@ -288,7 +306,7 @@ func TestSummarize(t *testing.T) {
 		name: "with SSL invalid cert",
 		args: args{
 			tk: &webconnectivity.TestKeys{
-				Requests: []archival.RequestEntry{{
+				Requests: []tracex.RequestEntry{{
 					Failure: &probeSSLInvalidCert,
 				}},
 			},
@@ -304,7 +322,7 @@ func TestSummarize(t *testing.T) {
 		name: "with SSL unknown auth",
 		args: args{
 			tk: &webconnectivity.TestKeys{
-				Requests: []archival.RequestEntry{{
+				Requests: []tracex.RequestEntry{{
 					Failure: &probeSSLUnknownAuth,
 				}},
 			},
@@ -323,7 +341,7 @@ func TestSummarize(t *testing.T) {
 				DNSAnalysisResult: webconnectivity.DNSAnalysisResult{
 					DNSConsistency: &webconnectivity.DNSInconsistent,
 				},
-				Requests: []archival.RequestEntry{{
+				Requests: []tracex.RequestEntry{{
 					Failure: &probeSSLUnknownAuth,
 				}},
 			},
@@ -343,7 +361,7 @@ func TestSummarize(t *testing.T) {
 				DNSAnalysisResult: webconnectivity.DNSAnalysisResult{
 					DNSConsistency: &webconnectivity.DNSInconsistent,
 				},
-				Requests: []archival.RequestEntry{{
+				Requests: []tracex.RequestEntry{{
 					Failure: &probeSSLUnknownAuth,
 				}, {}},
 			},
@@ -363,7 +381,7 @@ func TestSummarize(t *testing.T) {
 					StatusCodeMatch: &trueValue,
 					BodyLengthMatch: &trueValue,
 				},
-				Requests: []archival.RequestEntry{{}},
+				Requests: []tracex.RequestEntry{{}},
 			},
 		},
 		wantOut: webconnectivity.Summary{
@@ -380,7 +398,7 @@ func TestSummarize(t *testing.T) {
 					StatusCodeMatch: &trueValue,
 					HeadersMatch:    &trueValue,
 				},
-				Requests: []archival.RequestEntry{{}},
+				Requests: []tracex.RequestEntry{{}},
 			},
 		},
 		wantOut: webconnectivity.Summary{
@@ -397,7 +415,7 @@ func TestSummarize(t *testing.T) {
 					StatusCodeMatch: &trueValue,
 					TitleMatch:      &trueValue,
 				},
-				Requests: []archival.RequestEntry{{}},
+				Requests: []tracex.RequestEntry{{}},
 			},
 		},
 		wantOut: webconnectivity.Summary{
@@ -414,7 +432,7 @@ func TestSummarize(t *testing.T) {
 					StatusCodeMatch: &falseValue,
 					TitleMatch:      &trueValue,
 				},
-				Requests: []archival.RequestEntry{{}},
+				Requests: []tracex.RequestEntry{{}},
 				DNSAnalysisResult: webconnectivity.DNSAnalysisResult{
 					DNSConsistency: &webconnectivity.DNSInconsistent,
 				},
@@ -435,7 +453,7 @@ func TestSummarize(t *testing.T) {
 					StatusCodeMatch: &falseValue,
 					TitleMatch:      &trueValue,
 				},
-				Requests: []archival.RequestEntry{{}},
+				Requests: []tracex.RequestEntry{{}},
 				DNSAnalysisResult: webconnectivity.DNSAnalysisResult{
 					DNSConsistency: &webconnectivity.DNSConsistent,
 				},
