@@ -12,7 +12,6 @@ import (
 	"github.com/ooni/probe-cli/v3/internal/atomicx"
 	"github.com/ooni/probe-cli/v3/internal/engine/experiment/urlgetter"
 	"github.com/ooni/probe-cli/v3/internal/engine/experiment/whatsapp"
-	"github.com/ooni/probe-cli/v3/internal/engine/internal/httpfailure"
 	"github.com/ooni/probe-cli/v3/internal/engine/mockable"
 	"github.com/ooni/probe-cli/v3/internal/model"
 )
@@ -28,6 +27,9 @@ func TestNewExperimentMeasurer(t *testing.T) {
 }
 
 func TestSuccess(t *testing.T) {
+	if testing.Short() {
+		t.Skip("skip test in short mode")
+	}
 	measurer := whatsapp.NewExperimentMeasurer(whatsapp.Config{})
 	ctx := context.Background()
 	sess := &mockable.Session{MockableLogger: log.Log}
@@ -411,7 +413,7 @@ func TestTestKeysOnlyWebHTTPFailureNo302(t *testing.T) {
 	if tk.WhatsappEndpointsStatus != "ok" {
 		t.Fatal("invalid WhatsappEndpointsStatus")
 	}
-	if *tk.WhatsappWebFailure != httpfailure.UnexpectedStatusCode {
+	if *tk.WhatsappWebFailure != model.HTTPUnexpectedStatusCode {
 		t.Fatal("invalid WhatsappWebFailure")
 	}
 	if tk.WhatsappWebStatus != "blocked" {
@@ -456,7 +458,7 @@ func TestTestKeysOnlyWebHTTPFailureNoLocations(t *testing.T) {
 	if tk.WhatsappEndpointsStatus != "ok" {
 		t.Fatal("invalid WhatsappEndpointsStatus")
 	}
-	if *tk.WhatsappWebFailure != httpfailure.UnexpectedRedirectURL {
+	if *tk.WhatsappWebFailure != model.HTTPUnexpectedRedirectURL {
 		t.Fatal("invalid WhatsappWebFailure")
 	}
 	if tk.WhatsappWebStatus != "blocked" {
@@ -501,7 +503,7 @@ func TestTestKeysOnlyWebHTTPFailureNotExpectedURL(t *testing.T) {
 	if tk.WhatsappEndpointsStatus != "ok" {
 		t.Fatal("invalid WhatsappEndpointsStatus")
 	}
-	if *tk.WhatsappWebFailure != httpfailure.UnexpectedRedirectURL {
+	if *tk.WhatsappWebFailure != model.HTTPUnexpectedRedirectURL {
 		t.Fatal("invalid WhatsappWebFailure")
 	}
 	if tk.WhatsappWebStatus != "blocked" {
@@ -546,7 +548,7 @@ func TestTestKeysOnlyWebHTTPFailureTooManyURLs(t *testing.T) {
 	if tk.WhatsappEndpointsStatus != "ok" {
 		t.Fatal("invalid WhatsappEndpointsStatus")
 	}
-	if *tk.WhatsappWebFailure != httpfailure.UnexpectedRedirectURL {
+	if *tk.WhatsappWebFailure != model.HTTPUnexpectedRedirectURL {
 		t.Fatal("invalid WhatsappWebFailure")
 	}
 	if tk.WhatsappWebStatus != "blocked" {
@@ -555,6 +557,9 @@ func TestTestKeysOnlyWebHTTPFailureTooManyURLs(t *testing.T) {
 }
 
 func TestWeConfigureWebChecksCorrectly(t *testing.T) {
+	if testing.Short() {
+		t.Skip("skip test in short mode")
+	}
 	called := &atomicx.Int64{}
 	emptyConfig := urlgetter.Config{}
 	configWithFailOnHTTPError := urlgetter.Config{FailOnHTTPError: true}
