@@ -5,42 +5,11 @@ import (
 	"context"
 	"fmt"
 
-	"github.com/ooni/probe-cli/v3/internal/engine/netx"
 	"github.com/ooni/probe-cli/v3/internal/model"
+	"github.com/ooni/probe-cli/v3/internal/netxlite"
 	"github.com/ooni/probe-cli/v3/internal/version"
 )
 
-const (
-	// DefaultProbeASN is the default probe ASN as a number.
-	DefaultProbeASN uint = 0
-
-	// DefaultProbeCC is the default probe CC.
-	DefaultProbeCC = "ZZ"
-
-	// DefaultProbeIP is the default probe IP.
-	DefaultProbeIP = model.DefaultProbeIP
-
-	// DefaultProbeNetworkName is the default probe network name.
-	DefaultProbeNetworkName = ""
-
-	// DefaultResolverASN is the default resolver ASN.
-	DefaultResolverASN uint = 0
-
-	// DefaultResolverIP is the default resolver IP.
-	DefaultResolverIP = "127.0.0.2"
-
-	// DefaultResolverNetworkName is the default resolver network name.
-	DefaultResolverNetworkName = ""
-)
-
-var (
-	// DefaultProbeASNString is the default probe ASN as a string.
-	DefaultProbeASNString = fmt.Sprintf("AS%d", DefaultProbeASN)
-
-	// DefaultResolverASNString is the default resolver ASN as a string.
-	DefaultResolverASNString = fmt.Sprintf("AS%d", DefaultResolverASN)
-)
-
 // Results contains geolocate results.
 type Results struct {
 	// ASN is the autonomous system number.
@@ -114,8 +83,7 @@ func NewTask(config Config) *Task {
 		config.UserAgent = fmt.Sprintf("ooniprobe-engine/%s", version.Version)
 	}
 	if config.Resolver == nil {
-		config.Resolver = netx.NewResolver(
-			netx.Config{Logger: config.Logger})
+		config.Resolver = netxlite.NewStdlibResolver(config.Logger)
 	}
 	return &Task{
 		countryLookupper:     mmdbLookupper{},
@@ -140,13 +108,13 @@ type Task struct {
 func (op Task) Run(ctx context.Context) (*Results, error) {
 	var err error
 	out := &Results{
-		ASN:                 DefaultProbeASN,
-		CountryCode:         DefaultProbeCC,
-		NetworkName:         DefaultProbeNetworkName,
-		ProbeIP:             DefaultProbeIP,
-		ResolverASN:         DefaultResolverASN,
-		ResolverIP:          DefaultResolverIP,
-		ResolverNetworkName: DefaultResolverNetworkName,
+		ASN:                 model.DefaultProbeASN,
+		CountryCode:         model.DefaultProbeCC,
+		NetworkName:         model.DefaultProbeNetworkName,
+		ProbeIP:             model.DefaultProbeIP,
+		ResolverASN:         model.DefaultResolverASN,
+		ResolverIP:          model.DefaultResolverIP,
+		ResolverNetworkName: model.DefaultResolverNetworkName,
 	}
 	ip, err := op.probeIPLookupper.LookupProbeIP(ctx)
 	if err != nil {
