@@ -7,11 +7,14 @@ import (
 	"testing"
 
 	"github.com/apex/log"
+	"github.com/ooni/probe-cli/v3/internal/model"
+	"github.com/ooni/probe-cli/v3/internal/netxlite"
 )
 
 func TestIPLookupGood(t *testing.T) {
 	ip, err := (ipLookupClient{
 		Logger:    log.Log,
+		Resolver:  netxlite.NewStdlibResolver(model.DiscardLogger),
 		UserAgent: "ooniprobe-engine/0.1.0",
 	}).LookupProbeIP(context.Background())
 	if err != nil {
@@ -27,12 +30,13 @@ func TestIPLookupAllFailed(t *testing.T) {
 	cancel() // immediately cancel to cause Do() to fail
 	ip, err := (ipLookupClient{
 		Logger:    log.Log,
+		Resolver:  netxlite.NewStdlibResolver(model.DiscardLogger),
 		UserAgent: "ooniprobe-engine/0.1.0",
 	}).LookupProbeIP(ctx)
 	if !errors.Is(err, context.Canceled) {
 		t.Fatal("expected an error here")
 	}
-	if ip != DefaultProbeIP {
+	if ip != model.DefaultProbeIP {
 		t.Fatal("expected the default IP here")
 	}
 }
@@ -41,12 +45,13 @@ func TestIPLookupInvalidIP(t *testing.T) {
 	ctx := context.Background()
 	ip, err := (ipLookupClient{
 		Logger:    log.Log,
+		Resolver:  netxlite.NewStdlibResolver(model.DiscardLogger),
 		UserAgent: "ooniprobe-engine/0.1.0",
 	}).doWithCustomFunc(ctx, invalidIPLookup)
 	if !errors.Is(err, ErrInvalidIPAddress) {
 		t.Fatal("expected an error here")
 	}
-	if ip != DefaultProbeIP {
+	if ip != model.DefaultProbeIP {
 		t.Fatal("expected the default IP here")
 	}
 }
