@@ -6,6 +6,9 @@ import (
 )
 
 func TestGetTestHelpers(t *testing.T) {
+	if testing.Short() {
+		t.Skip("skip test in short mode")
+	}
 	testhelpers, err := newclient().GetTestHelpers(context.Background())
 	if err != nil {
 		t.Fatal(err)
