@@ -14,9 +14,12 @@ import (
 )
 
 func TestCheckReportIDWorkingAsIntended(t *testing.T) {
+	if testing.Short() {
+		t.Skip("skip test in short mode")
+	}
 	client := probeservices.Client{
 		APIClientTemplate: httpx.APIClientTemplate{
-			BaseURL:    "https://ams-pg.ooni.org/",
+			BaseURL:    "https://api.ooni.io/",
 			HTTPClient: http.DefaultClient,
 			Logger:     log.Log,
 			UserAgent:  "miniooni/0.1.0-dev",
@@ -39,7 +42,7 @@ func TestCheckReportIDWorkingAsIntended(t *testing.T) {
 func TestCheckReportIDWorkingWithCancelledContext(t *testing.T) {
 	client := probeservices.Client{
 		APIClientTemplate: httpx.APIClientTemplate{
-			BaseURL:    "https://ams-pg.ooni.org/",
+			BaseURL:    "https://api.ooni.io/",
 			HTTPClient: http.DefaultClient,
 			Logger:     log.Log,
 			UserAgent:  "miniooni/0.1.0-dev",
