@@ -3,7 +3,7 @@ package probeservices
 import (
 	"context"
 
-	"github.com/ooni/probe-cli/v3/internal/engine/internal/randx"
+	"github.com/ooni/probe-cli/v3/internal/randx"
 )
 
 type registerRequest struct {
@@ -25,13 +25,16 @@ func (c Client) MaybeRegister(ctx context.Context, metadata Metadata) error {
 		return nil // we're already good
 	}
 	c.RegisterCalls.Add(1)
+	// TODO(bassosimone): here we should use a CSRNG
+	// (https://github.com/ooni/probe/issues/1502)
 	pwd := randx.Letters(64)
 	req := &registerRequest{
 		Metadata: metadata,
 		Password: pwd,
 	}
 	var resp registerResult
-	if err := c.Client.PostJSON(ctx, "/api/v1/register", req, &resp); err != nil {
+	if err := c.APIClientTemplate.Build().PostJSON(
+		ctx, "/api/v1/register", req, &resp); err != nil {
 		return err
 	}
 	state.ClientID = resp.ClientID
