@@ -5,17 +5,17 @@ import (
 	"fmt"
 	"net/url"
 
-	"github.com/ooni/probe-cli/v3/internal/engine/model"
+	"github.com/ooni/probe-cli/v3/internal/model"
 )
 
 // FetchTorTargets returns the targets for the tor experiment.
-func (c Client) FetchTorTargets(ctx context.Context, cc string) (result map[string]model.TorTarget, err error) {
+func (c Client) FetchTorTargets(ctx context.Context, cc string) (result map[string]model.OOAPITorTarget, err error) {
 	_, auth, err := c.GetCredsAndAuth()
 	if err != nil {
 		return nil, err
 	}
-	client := c.Client
-	client.Authorization = fmt.Sprintf("Bearer %s", auth.Token)
+	s := fmt.Sprintf("Bearer %s", auth.Token)
+	client := c.APIClientTemplate.BuildWithAuthorization(s)
 	query := url.Values{}
 	query.Add("country_code", cc)
 	err = client.GetJSONWithQuery(
