@@ -5,13 +5,16 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/ooni/probe-cli/v3/internal/engine/model"
+	"github.com/ooni/probe-cli/v3/internal/model"
 )
 
 func TestFetchURLListSuccess(t *testing.T) {
+	if testing.Short() {
+		t.Skip("skip test in short mode")
+	}
 	client := newclient()
 	client.BaseURL = "https://ams-pg-test.ooni.org"
-	config := model.URLListConfig{
+	config := model.OOAPIURLListConfig{
 		Categories:  []string{"NEWS", "CULTR"},
 		CountryCode: "IT",
 		Limit:       17,
@@ -34,7 +37,7 @@ func TestFetchURLListSuccess(t *testing.T) {
 func TestFetchURLListFailure(t *testing.T) {
 	client := newclient()
 	client.BaseURL = "https://\t\t\t/" // cause test to fail
-	config := model.URLListConfig{
+	config := model.OOAPIURLListConfig{
 		Categories:  []string{"NEWS", "CULTR"},
 		CountryCode: "IT",
 		Limit:       17,
