@@ -13,11 +13,11 @@ import (
 	"github.com/ooni/probe-cli/v3/internal/atomicx"
 	"github.com/ooni/probe-cli/v3/internal/bytecounter"
 	"github.com/ooni/probe-cli/v3/internal/engine/geolocate"
-	"github.com/ooni/probe-cli/v3/internal/engine/internal/sessionresolver"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx"
 	"github.com/ooni/probe-cli/v3/internal/engine/probeservices"
+	"github.com/ooni/probe-cli/v3/internal/engine/sessionresolver"
 	"github.com/ooni/probe-cli/v3/internal/kvstore"
 	"github.com/ooni/probe-cli/v3/internal/model"
+	"github.com/ooni/probe-cli/v3/internal/netxlite"
 	"github.com/ooni/probe-cli/v3/internal/platform"
 	"github.com/ooni/probe-cli/v3/internal/tunnel"
 	"github.com/ooni/probe-cli/v3/internal/version"
@@ -191,20 +191,17 @@ func NewSession(ctx context.Context, config SessionConfig) (*Session, error) {
 		}
 	}
 	sess.proxyURL = proxyURL
-	httpConfig := netx.Config{
-		ByteCounter:  sess.byteCounter,
-		BogonIsError: true,
-		Logger:       sess.logger,
-		ProxyURL:     proxyURL,
-	}
 	sess.resolver = &sessionresolver.Resolver{
 		ByteCounter: sess.byteCounter,
 		KVStore:     config.KVStore,
 		Logger:      sess.logger,
 		ProxyURL:    proxyURL,
 	}
-	httpConfig.FullResolver = sess.resolver
-	sess.httpDefaultTransport = netx.NewHTTPTransport(httpConfig)
+	txp := netxlite.NewHTTPTransportWithLoggerResolverAndOptionalProxyURL(
+		sess.logger, sess.resolver, sess.proxyURL,
+	)
+	txp = bytecounter.WrapHTTPTransport(txp, sess.byteCounter)
+	sess.httpDefaultTransport = txp
 	return sess, nil
 }
 
@@ -238,7 +235,7 @@ func (s *Session) KibiBytesSent() float64 {
 //
 // - ProbeCC: if empty, set to Session.ProbeCC();
 //
-// - RunType: if empty, set to "timed";
+// - RunType: if empty, set to model.RunTypeTimed;
 //
 // - SoftwareName: if empty, set to Session.SoftwareName();
 //
@@ -270,7 +267,7 @@ func (s *Session) CheckIn(
 		config.ProbeCC = s.ProbeCC()
 	}
 	if config.RunType == "" {
-		config.RunType = "timed" // most conservative choice
+		config.RunType = model.RunTypeTimed // most conservative choice
 	}
 	if config.SoftwareName == "" {
 		config.SoftwareName = s.SoftwareName()
@@ -340,7 +337,7 @@ func (s *Session) GetTestHelpersByName(name string) ([]model.OOAPIService, bool)
 }
 
 // DefaultHTTPClient returns the session's default HTTP client.
-func (s *Session) DefaultHTTPClient() *http.Client {
+func (s *Session) DefaultHTTPClient() model.HTTPClient {
 	return &http.Client{Transport: s.httpDefaultTransport}
 }
 
@@ -393,8 +390,12 @@ var ErrAlreadyUsingProxy = errors.New(
 // NewExperimentBuilder returns a new experiment builder
 // for the experiment with the given name, or an error if
 // there's no such experiment with the given name
-func (s *Session) NewExperimentBuilder(name string) (*ExperimentBuilder, error) {
-	return newExperimentBuilder(s, name)
+func (s *Session) NewExperimentBuilder(name string) (model.ExperimentBuilder, error) {
+	eb, err := newExperimentBuilder(s, name)
+	if err != nil {
+		return nil, err
+	}
+	return eb, nil
 }
 
 // NewProbeServicesClient creates a new client for talking with the
@@ -465,7 +466,7 @@ func (s *Session) ProbeASNString() string {
 func (s *Session) ProbeASN() uint {
 	defer s.mu.Unlock()
 	s.mu.Lock()
-	asn := geolocate.DefaultProbeASN
+	asn := model.DefaultProbeASN
 	if s.location != nil {
 		asn = s.location.ASN
 	}
@@ -476,7 +477,7 @@ func (s *Session) ProbeASN() uint {
 func (s *Session) ProbeCC() string {
 	defer s.mu.Unlock()
 	s.mu.Lock()
-	cc := geolocate.DefaultProbeCC
+	cc := model.DefaultProbeCC
 	if s.location != nil {
 		cc = s.location.CountryCode
 	}
@@ -487,7 +488,7 @@ func (s *Session) ProbeCC() string {
 func (s *Session) ProbeNetworkName() string {
 	defer s.mu.Unlock()
 	s.mu.Lock()
-	nn := geolocate.DefaultProbeNetworkName
+	nn := model.DefaultProbeNetworkName
 	if s.location != nil {
 		nn = s.location.NetworkName
 	}
@@ -498,7 +499,7 @@ func (s *Session) ProbeNetworkName() string {
 func (s *Session) ProbeIP() string {
 	defer s.mu.Unlock()
 	s.mu.Lock()
-	ip := geolocate.DefaultProbeIP
+	ip := model.DefaultProbeIP
 	if s.location != nil {
 		ip = s.location.ProbeIP
 	}
@@ -519,7 +520,7 @@ func (s *Session) ResolverASNString() string {
 func (s *Session) ResolverASN() uint {
 	defer s.mu.Unlock()
 	s.mu.Lock()
-	asn := geolocate.DefaultResolverASN
+	asn := model.DefaultResolverASN
 	if s.location != nil {
 		asn = s.location.ResolverASN
 	}
@@ -530,7 +531,7 @@ func (s *Session) ResolverASN() uint {
 func (s *Session) ResolverIP() string {
 	defer s.mu.Unlock()
 	s.mu.Lock()
-	ip := geolocate.DefaultResolverIP
+	ip := model.DefaultResolverIP
 	if s.location != nil {
 		ip = s.location.ResolverIP
 	}
@@ -541,7 +542,7 @@ func (s *Session) ResolverIP() string {
 func (s *Session) ResolverNetworkName() string {
 	defer s.mu.Unlock()
 	s.mu.Lock()
-	nn := geolocate.DefaultResolverNetworkName
+	nn := model.DefaultResolverNetworkName
 	if s.location != nil {
 		nn = s.location.ResolverNetworkName
 	}
