@@ -13,10 +13,10 @@ import (
 	"testing"
 
 	"github.com/google/go-cmp/cmp"
-	"github.com/ooni/probe-cli/v3/internal/fakefill"
 	"github.com/ooni/probe-cli/v3/internal/model"
 	"github.com/ooni/probe-cli/v3/internal/model/mocks"
 	"github.com/ooni/probe-cli/v3/internal/netxlite"
+	"github.com/ooni/probe-cli/v3/internal/testingx"
 	"github.com/ooni/probe-cli/v3/internal/version"
 )
 
@@ -47,7 +47,7 @@ func TestAPIClientTemplate(t *testing.T) {
 			HTTPClient: http.DefaultClient,
 			Logger:     model.DiscardLogger,
 		}
-		ff := &fakefill.Filler{}
+		ff := &testingx.FakeFiller{}
 		ff.Fill(tmpl)
 		ac := tmpl.Build()
 		orig := apiClient(*tmpl)
@@ -64,7 +64,7 @@ func TestAPIClientTemplate(t *testing.T) {
 			HTTPClient: http.DefaultClient,
 			Logger:     model.DiscardLogger,
 		}
-		ff := &fakefill.Filler{}
+		ff := &testingx.FakeFiller{}
 		ff.Fill(tmpl)
 		tok := ""
 		ff.Fill(&tok)
@@ -93,6 +93,92 @@ func newAPIClient() *apiClient {
 	}
 }
 
+func TestJoinURLPath(t *testing.T) {
+	t.Run("the whole path is inside basePath and there's no resource path", func(t *testing.T) {
+		ac := newAPIClient()
+		ac.BaseURL = "https://example.com/robots.txt"
+		req, err := ac.newRequest(context.Background(), "GET", "", nil, nil)
+		if err != nil {
+			t.Fatal(err)
+		}
+		if req.URL.String() != "https://example.com/robots.txt" {
+			t.Fatal("unexpected result", req.URL.String())
+		}
+	})
+
+	t.Run("empty baseURL path and slash-prefixed resource path", func(t *testing.T) {
+		ac := newAPIClient()
+		ac.BaseURL = "https://example.com"
+		req, err := ac.newRequest(context.Background(), "GET", "/foo", nil, nil)
+		if err != nil {
+			t.Fatal(err)
+		}
+		if req.URL.String() != "https://example.com/foo" {
+			t.Fatal("unexpected result", req.URL.String())
+		}
+	})
+
+	t.Run("root baseURL path and slash-prefixed resource path", func(t *testing.T) {
+		ac := newAPIClient()
+		ac.BaseURL = "https://example.com/"
+		req, err := ac.newRequest(context.Background(), "GET", "/foo", nil, nil)
+		if err != nil {
+			t.Fatal(err)
+		}
+		if req.URL.String() != "https://example.com/foo" {
+			t.Fatal("unexpected result", req.URL.String())
+		}
+	})
+
+	t.Run("empty baseURL path and empty resource path", func(t *testing.T) {
+		ac := newAPIClient()
+		ac.BaseURL = "https://example.com"
+		req, err := ac.newRequest(context.Background(), "GET", "", nil, nil)
+		if err != nil {
+			t.Fatal(err)
+		}
+		if req.URL.String() != "https://example.com/" {
+			t.Fatal("unexpected result", req.URL.String())
+		}
+	})
+
+	t.Run("non-slash-terminated baseURL path and slash-prefixed resource path", func(t *testing.T) {
+		ac := newAPIClient()
+		ac.BaseURL = "http://example.com/foo"
+		req, err := ac.newRequest(context.Background(), "GET", "/bar", nil, nil)
+		if err != nil {
+			t.Fatal(err)
+		}
+		if req.URL.String() != "http://example.com/foo/bar" {
+			t.Fatal("unexpected result", req.URL.String())
+		}
+	})
+
+	t.Run("slash-terminated baseURL path and slash-prefixed resource path", func(t *testing.T) {
+		ac := newAPIClient()
+		ac.BaseURL = "http://example.com/foo/"
+		req, err := ac.newRequest(context.Background(), "GET", "/bar", nil, nil)
+		if err != nil {
+			t.Fatal(err)
+		}
+		if req.URL.String() != "http://example.com/foo/bar" {
+			t.Fatal("unexpected result", req.URL.String())
+		}
+	})
+
+	t.Run("slash-terminated baseURL path and non-slash-prefixed resource path", func(t *testing.T) {
+		ac := newAPIClient()
+		ac.BaseURL = "http://example.com/foo/"
+		req, err := ac.newRequest(context.Background(), "GET", "bar", nil, nil)
+		if err != nil {
+			t.Fatal(err)
+		}
+		if req.URL.String() != "http://example.com/foo/bar" {
+			t.Fatal("unexpected result", req.URL.String())
+		}
+	})
+}
+
 // fakeRequest is a fake request we serialize.
 type fakeRequest struct {
 	Name       string
@@ -132,7 +218,7 @@ func TestAPIClient(t *testing.T) {
 
 		t.Run("sets the content-type properly", func(t *testing.T) {
 			var jsonReq fakeRequest
-			ff := &fakefill.Filler{}
+			ff := &testingx.FakeFiller{}
 			ff.Fill(&jsonReq)
 			client := newAPIClient()
 			req, err := client.newRequestWithJSONBody(
