@@ -11,32 +11,78 @@ import (
 	"time"
 
 	"github.com/apex/log"
+	"github.com/ooni/probe-cli/v3/internal/model"
 	"github.com/ooni/probe-cli/v3/internal/model/mocks"
+	"github.com/ooni/probe-cli/v3/internal/testingx"
 )
 
+func TestNewDialerWithStdlibResolver(t *testing.T) {
+	dialer := NewDialerWithStdlibResolver(model.DiscardLogger)
+	logger := dialer.(*dialerLogger)
+	if logger.DebugLogger != model.DiscardLogger {
+		t.Fatal("invalid logger")
+	}
+	// typecheck the resolver
+	reso := logger.Dialer.(*dialerResolverWithTracing)
+	typecheckForSystemResolver(t, reso.Resolver, model.DiscardLogger)
+	// typecheck the dialer
+	logger = reso.Dialer.(*dialerLogger)
+	if logger.DebugLogger != model.DiscardLogger {
+		t.Fatal("invalid logger")
+	}
+	errWrapper := logger.Dialer.(*dialerErrWrapper)
+	_ = errWrapper.Dialer.(*DialerSystem)
+}
+
+type extensionDialerFirst struct {
+	model.Dialer
+}
+
+type dialerWrapperFirst struct{}
+
+func (*dialerWrapperFirst) WrapDialer(d model.Dialer) model.Dialer {
+	return &extensionDialerFirst{d}
+}
+
+type extensionDialerSecond struct {
+	model.Dialer
+}
+
+type dialerWrapperSecond struct{}
+
+func (*dialerWrapperSecond) WrapDialer(d model.Dialer) model.Dialer {
+	return &extensionDialerSecond{d}
+}
 func TestNewDialer(t *testing.T) {
 	t.Run("produces a chain with the expected types", func(t *testing.T) {
-		d := NewDialerWithoutResolver(log.Log)
+		modifiers := []model.DialerWrapper{
+			&dialerWrapperFirst{},
+			nil, // explicitly test for this documented case
+			&dialerWrapperSecond{},
+		}
+		d := NewDialerWithoutResolver(log.Log, modifiers...)
 		logger := d.(*dialerLogger)
 		if logger.DebugLogger != log.Log {
 			t.Fatal("invalid logger")
 		}
-		reso := logger.Dialer.(*dialerResolver)
-		if _, okay := reso.Resolver.(*nullResolver); !okay {
+		reso := logger.Dialer.(*dialerResolverWithTracing)
+		if _, okay := reso.Resolver.(*NullResolver); !okay {
 			t.Fatal("invalid Resolver type")
 		}
 		logger = reso.Dialer.(*dialerLogger)
 		if logger.DebugLogger != log.Log {
 			t.Fatal("invalid logger")
 		}
-		errWrapper := logger.Dialer.(*dialerErrWrapper)
-		_ = errWrapper.Dialer.(*dialerSystem)
+		ext2 := logger.Dialer.(*extensionDialerSecond)
+		ext1 := ext2.Dialer.(*extensionDialerFirst)
+		errWrapper := ext1.Dialer.(*dialerErrWrapper)
+		_ = errWrapper.Dialer.(*DialerSystem)
 	})
 }
 
 func TestDialerSystem(t *testing.T) {
 	t.Run("has a default timeout", func(t *testing.T) {
-		d := &dialerSystem{}
+		d := &DialerSystem{}
 		ud := d.newUnderlyingDialer()
 		if ud.(*net.Dialer).Timeout != dialerDefaultTimeout {
 			t.Fatal("unexpected default timeout")
@@ -45,7 +91,7 @@ func TestDialerSystem(t *testing.T) {
 
 	t.Run("we can change the timeout for testing", func(t *testing.T) {
 		const smaller = 1 * time.Second
-		d := &dialerSystem{timeout: smaller}
+		d := &DialerSystem{timeout: smaller}
 		ud := d.newUnderlyingDialer()
 		if ud.(*net.Dialer).Timeout != smaller {
 			t.Fatal("unexpected timeout")
@@ -53,13 +99,13 @@ func TestDialerSystem(t *testing.T) {
 	})
 
 	t.Run("CloseIdleConnections", func(t *testing.T) {
-		d := &dialerSystem{}
+		d := &DialerSystem{}
 		d.CloseIdleConnections() // to avoid missing coverage
 	})
 
 	t.Run("DialContext", func(t *testing.T) {
 		t.Run("with canceled context", func(t *testing.T) {
-			d := &dialerSystem{}
+			d := &DialerSystem{}
 			ctx, cancel := context.WithCancel(context.Background())
 			cancel() // immediately!
 			conn, err := d.DialContext(ctx, "tcp", "8.8.8.8:443")
@@ -73,7 +119,7 @@ func TestDialerSystem(t *testing.T) {
 
 		t.Run("enforces the configured timeout", func(t *testing.T) {
 			const timeout = 1 * time.Nanosecond
-			d := &dialerSystem{timeout: timeout}
+			d := &DialerSystem{timeout: timeout}
 			ctx := context.Background()
 			start := time.Now()
 			conn, err := d.DialContext(ctx, "tcp", "dns.google:443")
@@ -91,12 +137,12 @@ func TestDialerSystem(t *testing.T) {
 	})
 }
 
-func TestDialerResolver(t *testing.T) {
+func TestDialerResolverWithTracing(t *testing.T) {
 	t.Run("DialContext", func(t *testing.T) {
 		t.Run("fails without a port", func(t *testing.T) {
-			d := &dialerResolver{
-				Dialer:   &dialerSystem{},
-				Resolver: &resolverSystem{},
+			d := &dialerResolverWithTracing{
+				Dialer:   &DialerSystem{},
+				Resolver: NewUnwrappedStdlibResolver(),
 			}
 			const missingPort = "ooni.nu"
 			conn, err := d.DialContext(context.Background(), "tcp", missingPort)
@@ -109,25 +155,38 @@ func TestDialerResolver(t *testing.T) {
 		})
 
 		t.Run("handles dialing error correctly for single IP address", func(t *testing.T) {
-			d := &dialerResolver{
+			d := &dialerResolverWithTracing{
 				Dialer: &mocks.Dialer{
 					MockDialContext: func(ctx context.Context, network string, address string) (net.Conn, error) {
 						return nil, io.EOF
 					},
 				},
-				Resolver: &nullResolver{},
+				Resolver: &NullResolver{},
 			}
 			conn, err := d.DialContext(context.Background(), "tcp", "1.1.1.1:853")
 			if !errors.Is(err, io.EOF) {
 				t.Fatal("not the error we expected")
 			}
+			var errWrapper *ErrWrapper
+			if !errors.As(err, &errWrapper) {
+				t.Fatal("the error has not been wrapped")
+			}
+			if errWrapper.Failure != FailureEOFError {
+				t.Fatal("invalid wrapped error's failure")
+			}
+			if errWrapper.Operation != ConnectOperation {
+				t.Fatal("invalid wrapped error's operation")
+			}
+			if !errors.Is(errWrapper.WrappedErr, io.EOF) {
+				t.Fatal("invalid wrapped error's underlying error")
+			}
 			if conn != nil {
 				t.Fatal("expected nil conn")
 			}
 		})
 
 		t.Run("handles dialing error correctly for many IP addresses", func(t *testing.T) {
-			d := &dialerResolver{
+			d := &dialerResolverWithTracing{
 				Dialer: &mocks.Dialer{
 					MockDialContext: func(ctx context.Context, network string, address string) (net.Conn, error) {
 						return nil, io.EOF
@@ -143,6 +202,19 @@ func TestDialerResolver(t *testing.T) {
 			if !errors.Is(err, io.EOF) {
 				t.Fatal("not the error we expected")
 			}
+			var errWrapper *ErrWrapper
+			if !errors.As(err, &errWrapper) {
+				t.Fatal("the error has not been wrapped")
+			}
+			if errWrapper.Failure != FailureEOFError {
+				t.Fatal("invalid wrapped error's failure")
+			}
+			if errWrapper.Operation != ConnectOperation {
+				t.Fatal("invalid wrapped error's operation")
+			}
+			if !errors.Is(errWrapper.WrappedErr, io.EOF) {
+				t.Fatal("invalid wrapped error's underlying error")
+			}
 			if conn != nil {
 				t.Fatal("expected nil conn")
 			}
@@ -154,7 +226,7 @@ func TestDialerResolver(t *testing.T) {
 					return nil
 				},
 			}
-			d := &dialerResolver{
+			d := &dialerResolverWithTracing{
 				Dialer: &mocks.Dialer{
 					MockDialContext: func(ctx context.Context, network string, address string) (net.Conn, error) {
 						return expectedConn, nil
@@ -170,7 +242,10 @@ func TestDialerResolver(t *testing.T) {
 			if err != nil {
 				t.Fatal(err)
 			}
-			if conn != expectedConn {
+			// Ensure that the dialer returns a connection that is already wrapping errors,
+			// which is a new behavior since https://github.com/ooni/probe-cli/pull/815
+			errWrapperConn := conn.(*dialerErrWrapperConn)
+			if errWrapperConn.Conn != expectedConn {
 				t.Fatal("unexpected conn")
 			}
 			conn.Close()
@@ -180,7 +255,7 @@ func TestDialerResolver(t *testing.T) {
 			// This test is fundamental to the following
 			// TODO(https://github.com/ooni/probe/issues/1779)
 			mu := &sync.Mutex{}
-			d := &dialerResolver{
+			d := &dialerResolverWithTracing{
 				Dialer: &mocks.Dialer{
 					MockDialContext: func(ctx context.Context, network string, address string) (net.Conn, error) {
 						// It should not happen to have parallel dials with
@@ -212,7 +287,7 @@ func TestDialerResolver(t *testing.T) {
 			// TODO(https://github.com/ooni/probe/issues/1779)
 			mu := &sync.Mutex{}
 			var attempts []string
-			d := &dialerResolver{
+			d := &dialerResolverWithTracing{
 				Dialer: &mocks.Dialer{
 					MockDialContext: func(ctx context.Context, network string, address string) (net.Conn, error) {
 						// It should not happen to have parallel dials with
@@ -254,13 +329,13 @@ func TestDialerResolver(t *testing.T) {
 			errorsList := []error{
 				errors.New("a mocked error"),
 				NewErrWrapper(
-					classifyGenericError,
+					ClassifyGenericError,
 					CloseOperation,
 					io.EOF,
 				),
 			}
 			var errorIdx int
-			d := &dialerResolver{
+			d := &dialerResolverWithTracing{
 				Dialer: &mocks.Dialer{
 					MockDialContext: func(ctx context.Context, network string, address string) (net.Conn, error) {
 						// It should not happen to have parallel dials with
@@ -292,17 +367,18 @@ func TestDialerResolver(t *testing.T) {
 		t.Run("though ignores the unknown failures", func(t *testing.T) {
 			// This test is fundamental to the following
 			// TODO(https://github.com/ooni/probe/issues/1779)
+			expectedErr := errors.New("a mocked error")
 			mu := &sync.Mutex{}
 			errorsList := []error{
-				errors.New("a mocked error"),
+				expectedErr,
 				NewErrWrapper(
-					classifyGenericError,
+					ClassifyGenericError,
 					CloseOperation,
-					errors.New("antani"),
+					errors.New("antani"), // this is an unknown failure and we should not return it
 				),
 			}
 			var errorIdx int
-			d := &dialerResolver{
+			d := &dialerResolverWithTracing{
 				Dialer: &mocks.Dialer{
 					MockDialContext: func(ctx context.Context, network string, address string) (net.Conn, error) {
 						// It should not happen to have parallel dials with
@@ -323,20 +399,97 @@ func TestDialerResolver(t *testing.T) {
 				},
 			}
 			conn, err := d.DialContext(context.Background(), "tcp", "dot.dns:853")
-			if err == nil || err.Error() != "a mocked error" {
+			if !errors.Is(err, expectedErr) {
 				t.Fatal("unexpected err", err)
 			}
+			var errWrapper *ErrWrapper
+			if !errors.As(err, &errWrapper) {
+				t.Fatal("error has not been wrapped")
+			}
+			if errWrapper.Failure != "unknown_failure: a mocked error" {
+				t.Fatal("unexpected wrapped error's failure")
+			}
+			if errWrapper.Operation != ConnectOperation {
+				t.Fatal("unexpected wrapped error's operation")
+			}
+			if !errors.Is(errWrapper.WrappedErr, expectedErr) {
+				t.Fatal("unexpected wrapped error's underlying error")
+			}
 			if conn != nil {
 				t.Fatal("expected nil conn")
 			}
 		})
+
+		t.Run("uses a context-injected custom trace", func(t *testing.T) {
+			var (
+				called       bool
+				domainOK     bool
+				networkOK    bool
+				remoteAddrOK bool
+				startTimeOK  bool
+				finishTimeOK bool
+				wrappedErr   bool
+			)
+			zeroTime := time.Now()
+			deterministicTime := testingx.NewTimeDeterministic(zeroTime)
+			tx := &mocks.Trace{
+				MockTimeNow: deterministicTime.Now,
+				MockOnConnectDone: func(started time.Time, network, domain, remoteAddr string, err error, finished time.Time) {
+					var ew *ErrWrapper
+					called = true
+					domainOK = (domain == "1.1.1.1")
+					networkOK = (network == "tcp")
+					remoteAddrOK = (remoteAddr == "1.1.1.1:853")
+					startTimeOK = (started.Sub(zeroTime) == 0)
+					finishTimeOK = (finished.Sub(zeroTime) == time.Second)
+					wrappedErr = errors.As(err, &ew) && ew.Failure == FailureEOFError
+				},
+			}
+			ctx := ContextWithTrace(context.Background(), tx)
+			d := &dialerResolverWithTracing{
+				Dialer: &mocks.Dialer{
+					MockDialContext: func(ctx context.Context, network string, address string) (net.Conn, error) {
+						return nil, io.EOF
+					},
+				},
+				Resolver: &NullResolver{},
+			}
+			conn, err := d.DialContext(ctx, "tcp", "1.1.1.1:853")
+			if !errors.Is(err, io.EOF) {
+				t.Fatal("not the error we expected")
+			}
+			if conn != nil {
+				t.Fatal("expected nil conn")
+			}
+			if !called {
+				t.Fatal("not called")
+			}
+			if !domainOK {
+				t.Fatal("domain was not okay")
+			}
+			if !networkOK {
+				t.Fatal("network was not okay")
+			}
+			if !remoteAddrOK {
+				t.Fatal("remoteAddr was not okay")
+			}
+			if !startTimeOK {
+				t.Fatal("start time was not okay")
+			}
+			if !finishTimeOK {
+				t.Fatal("finish time was not okay")
+			}
+			if !wrappedErr {
+				t.Fatal("not wrapped")
+			}
+		})
 	})
 
 	t.Run("lookupHost", func(t *testing.T) {
 		t.Run("handles addresses correctly", func(t *testing.T) {
-			dialer := &dialerResolver{
-				Dialer:   &dialerSystem{},
-				Resolver: &nullResolver{},
+			dialer := &dialerResolverWithTracing{
+				Dialer:   &DialerSystem{},
+				Resolver: &NullResolver{},
 			}
 			addrs, err := dialer.lookupHost(context.Background(), "1.1.1.1")
 			if err != nil {
@@ -348,9 +501,9 @@ func TestDialerResolver(t *testing.T) {
 		})
 
 		t.Run("fails correctly on lookup error", func(t *testing.T) {
-			dialer := &dialerResolver{
-				Dialer:   &dialerSystem{},
-				Resolver: &nullResolver{},
+			dialer := &dialerResolverWithTracing{
+				Dialer:   &DialerSystem{},
+				Resolver: &NullResolver{},
 			}
 			ctx := context.Background()
 			conn, err := dialer.DialContext(ctx, "tcp", "dns.google.com:853")
@@ -368,7 +521,7 @@ func TestDialerResolver(t *testing.T) {
 			calledDialer   bool
 			calledResolver bool
 		)
-		d := &dialerResolver{
+		d := &dialerResolverWithTracing{
 			Dialer: &mocks.Dialer{
 				MockCloseIdleConnections: func() {
 					calledDialer = true
