@@ -12,11 +12,11 @@ import (
 // DEPRECATED: please use QUICDialer.
 type QUICContextDialer struct {
 	MockDialContext func(ctx context.Context, network, address string,
-		tlsConfig *tls.Config, quicConfig *quic.Config) (quic.EarlySession, error)
+		tlsConfig *tls.Config, quicConfig *quic.Config) (quic.EarlyConnection, error)
 }
 
 // DialContext calls MockDialContext.
 func (qcd *QUICContextDialer) DialContext(ctx context.Context, network, address string,
-	tlsConfig *tls.Config, quicConfig *quic.Config) (quic.EarlySession, error) {
+	tlsConfig *tls.Config, quicConfig *quic.Config) (quic.EarlyConnection, error) {
 	return qcd.MockDialContext(ctx, network, address, tlsConfig, quicConfig)
 }
