@@ -1,5 +1,9 @@
 package netxlite
 
+//
+// Names of operations
+//
+
 // Operations that we measure. They are the possible values of
 // the ErrWrapper.Operation field.
 const (
@@ -9,6 +13,9 @@ const (
 	// ConnectOperation is the operation where we do a TCP connect.
 	ConnectOperation = "connect"
 
+	// DNSRoundTripOperation is the DNS round trip.
+	DNSRoundTripOperation = "dns_round_trip"
+
 	// TLSHandshakeOperation is the TLS handshake.
 	TLSHandshakeOperation = "tls_handshake"
 
