@@ -22,28 +22,106 @@ func TestNewQUICListener(t *testing.T) {
 	_ = qew.QUICListener.(*quicListenerStdlib)
 }
 
+type extensionQUICDialerFirst struct {
+	model.QUICDialer
+}
+
+type quicDialerWrapperFirst struct{}
+
+func (*quicDialerWrapperFirst) WrapQUICDialer(qd model.QUICDialer) model.QUICDialer {
+	return &extensionQUICDialerFirst{qd}
+}
+
+type extensionQUICDialerSecond struct {
+	model.QUICDialer
+}
+
+type quicDialerWrapperSecond struct {
+	model.QUICDialer
+}
+
+func (*quicDialerWrapperSecond) WrapQUICDialer(qd model.QUICDialer) model.QUICDialer {
+	return &extensionQUICDialerSecond{qd}
+}
+
 func TestNewQUICDialer(t *testing.T) {
 	ql := NewQUICListener()
-	dlr := NewQUICDialerWithoutResolver(ql, log.Log)
+	extensions := []model.QUICDialerWrapper{
+		&quicDialerWrapperFirst{},
+		nil, // explicitly test for this documented case
+		&quicDialerWrapperSecond{},
+	}
+	dlr := NewQUICDialerWithoutResolver(ql, log.Log, extensions...)
 	logger := dlr.(*quicDialerLogger)
 	if logger.Logger != log.Log {
 		t.Fatal("invalid logger")
 	}
 	resolver := logger.Dialer.(*quicDialerResolver)
-	if _, okay := resolver.Resolver.(*nullResolver); !okay {
+	if _, okay := resolver.Resolver.(*NullResolver); !okay {
 		t.Fatal("invalid resolver type")
 	}
 	logger = resolver.Dialer.(*quicDialerLogger)
 	if logger.Logger != log.Log {
 		t.Fatal("invalid logger")
 	}
-	errWrapper := logger.Dialer.(*quicDialerErrWrapper)
-	base := errWrapper.QUICDialer.(*quicDialerQUICGo)
+	ext2 := logger.Dialer.(*extensionQUICDialerSecond)
+	ext1 := ext2.QUICDialer.(*extensionQUICDialerFirst)
+	errWrapper := ext1.QUICDialer.(*quicDialerErrWrapper)
+	handshakeCompleter := errWrapper.QUICDialer.(*quicDialerHandshakeCompleter)
+	base := handshakeCompleter.Dialer.(*quicDialerQUICGo)
 	if base.QUICListener != ql {
 		t.Fatal("invalid quic listener")
 	}
 }
 
+func TestParseUDPAddr(t *testing.T) {
+	t.Run("cannot split host and port", func(t *testing.T) {
+		addr, err := ParseUDPAddr("1.2.3.4")
+		if err == nil || !strings.HasSuffix(err.Error(), "missing port in address") {
+			t.Fatal("unexpected error", err)
+		}
+		if addr != nil {
+			t.Fatal("expected nil addr")
+		}
+	})
+
+	t.Run("with invalid IP addr", func(t *testing.T) {
+		addr, err := ParseUDPAddr("www.google.com:80")
+		if !errors.Is(err, ErrInvalidIP) {
+			t.Fatal("unexpected error", err)
+		}
+		if addr != nil {
+			t.Fatal("expected nil addr")
+		}
+	})
+
+	t.Run("with invalid port", func(t *testing.T) {
+		addr, err := ParseUDPAddr("8.8.8.8:www")
+		if err == nil || !strings.HasSuffix(err.Error(), "invalid syntax") {
+			t.Fatal("unexpected error", err)
+		}
+		if addr != nil {
+			t.Fatal("expected nil addr")
+		}
+	})
+
+	t.Run("with valid input", func(t *testing.T) {
+		addr, err := ParseUDPAddr("8.8.8.8:80")
+		if err != nil {
+			t.Fatal(err)
+		}
+		if addr.IP.String() != "8.8.8.8" {
+			t.Fatal("invalid IP")
+		}
+		if addr.Port != 80 {
+			t.Fatal("invalid port")
+		}
+		if addr.Zone != "" {
+			t.Fatal("invalid zone")
+		}
+	})
+}
+
 func TestQUICDialerQUICGo(t *testing.T) {
 	t.Run("DialContext", func(t *testing.T) {
 		t.Run("cannot split host port", func(t *testing.T) {
@@ -55,13 +133,13 @@ func TestQUICDialerQUICGo(t *testing.T) {
 			}
 			defer systemdialer.CloseIdleConnections() // just to see it running
 			ctx := context.Background()
-			sess, err := systemdialer.DialContext(
-				ctx, "udp", "a.b.c.d", tlsConfig, &quic.Config{})
+			qconn, err := systemdialer.DialContext(
+				ctx, "a.b.c.d", tlsConfig, &quic.Config{})
 			if err == nil || !strings.HasSuffix(err.Error(), "missing port in address") {
 				t.Fatal("not the error we expected", err)
 			}
-			if sess != nil {
-				t.Fatal("expected nil sess here")
+			if qconn != nil {
+				t.Fatal("expected nil connection here")
 			}
 		})
 
@@ -73,13 +151,13 @@ func TestQUICDialerQUICGo(t *testing.T) {
 				QUICListener: &quicListenerStdlib{},
 			}
 			ctx := context.Background()
-			sess, err := systemdialer.DialContext(
-				ctx, "udp", "8.8.4.4:xyz", tlsConfig, &quic.Config{})
+			qconn, err := systemdialer.DialContext(
+				ctx, "8.8.4.4:xyz", tlsConfig, &quic.Config{})
 			if err == nil || !strings.HasSuffix(err.Error(), "invalid syntax") {
 				t.Fatal("not the error we expected", err)
 			}
-			if sess != nil {
-				t.Fatal("expected nil sess here")
+			if qconn != nil {
+				t.Fatal("expected nil connection here")
 			}
 		})
 
@@ -91,13 +169,13 @@ func TestQUICDialerQUICGo(t *testing.T) {
 				QUICListener: &quicListenerStdlib{},
 			}
 			ctx := context.Background()
-			sess, err := systemdialer.DialContext(
-				ctx, "udp", "a.b.c.d:0", tlsConfig, &quic.Config{})
-			if !errors.Is(err, errInvalidIP) {
+			qconn, err := systemdialer.DialContext(
+				ctx, "a.b.c.d:0", tlsConfig, &quic.Config{})
+			if !errors.Is(err, ErrInvalidIP) {
 				t.Fatal("not the error we expected", err)
 			}
-			if sess != nil {
-				t.Fatal("expected nil sess here")
+			if qconn != nil {
+				t.Fatal("expected nil connection here")
 			}
 		})
 
@@ -114,13 +192,13 @@ func TestQUICDialerQUICGo(t *testing.T) {
 				},
 			}
 			ctx := context.Background()
-			sess, err := systemdialer.DialContext(
-				ctx, "udp", "8.8.8.8:443", tlsConfig, &quic.Config{})
+			qconn, err := systemdialer.DialContext(
+				ctx, "8.8.8.8:443", tlsConfig, &quic.Config{})
 			if !errors.Is(err, expected) {
 				t.Fatal("not the error we expected", err)
 			}
-			if sess != nil {
-				t.Fatal("expected nil sess here")
+			if qconn != nil {
+				t.Fatal("expected nil connection here")
 			}
 		})
 
@@ -133,13 +211,13 @@ func TestQUICDialerQUICGo(t *testing.T) {
 			}
 			ctx, cancel := context.WithCancel(context.Background())
 			cancel() // fail immediately
-			sess, err := systemdialer.DialContext(
-				ctx, "udp", "8.8.8.8:443", tlsConfig, &quic.Config{})
+			qconn, err := systemdialer.DialContext(
+				ctx, "8.8.8.8:443", tlsConfig, &quic.Config{})
 			if !errors.Is(err, context.Canceled) {
 				t.Fatal("not the error we expected", err)
 			}
-			if sess != nil {
-				log.Fatal("expected nil session here")
+			if qconn != nil {
+				log.Fatal("expected nil connection here")
 			}
 		})
 
@@ -153,19 +231,19 @@ func TestQUICDialerQUICGo(t *testing.T) {
 				QUICListener: &quicListenerStdlib{},
 				mockDialEarlyContext: func(ctx context.Context, pconn net.PacketConn,
 					remoteAddr net.Addr, host string, tlsConfig *tls.Config,
-					quicConfig *quic.Config) (quic.EarlySession, error) {
+					quicConfig *quic.Config) (quic.EarlyConnection, error) {
 					gotTLSConfig = tlsConfig
 					return nil, expected
 				},
 			}
 			ctx := context.Background()
-			sess, err := systemdialer.DialContext(
-				ctx, "udp", "8.8.8.8:443", tlsConfig, &quic.Config{})
+			qconn, err := systemdialer.DialContext(
+				ctx, "8.8.8.8:443", tlsConfig, &quic.Config{})
 			if !errors.Is(err, expected) {
 				t.Fatal("not the error we expected", err)
 			}
-			if sess != nil {
-				t.Fatal("expected nil session here")
+			if qconn != nil {
+				t.Fatal("expected nil connection here")
 			}
 			if tlsConfig.RootCAs != nil {
 				t.Fatal("tlsConfig.RootCAs should not have been changed")
@@ -194,19 +272,19 @@ func TestQUICDialerQUICGo(t *testing.T) {
 				QUICListener: &quicListenerStdlib{},
 				mockDialEarlyContext: func(ctx context.Context, pconn net.PacketConn,
 					remoteAddr net.Addr, host string, tlsConfig *tls.Config,
-					quicConfig *quic.Config) (quic.EarlySession, error) {
+					quicConfig *quic.Config) (quic.EarlyConnection, error) {
 					gotTLSConfig = tlsConfig
 					return nil, expected
 				},
 			}
 			ctx := context.Background()
-			sess, err := systemdialer.DialContext(
-				ctx, "udp", "8.8.8.8:8853", tlsConfig, &quic.Config{})
+			qconn, err := systemdialer.DialContext(
+				ctx, "8.8.8.8:8853", tlsConfig, &quic.Config{})
 			if !errors.Is(err, expected) {
 				t.Fatal("not the error we expected", err)
 			}
-			if sess != nil {
-				t.Fatal("expected nil session here")
+			if qconn != nil {
+				t.Fatal("expected nil connection here")
 			}
 			if tlsConfig.RootCAs != nil {
 				t.Fatal("tlsConfig.RootCAs should not have been changed")
@@ -224,9 +302,162 @@ func TestQUICDialerQUICGo(t *testing.T) {
 				t.Fatal("the ServerName field must match")
 			}
 		})
+
+		t.Run("returns a quicDialerOwnConn in case of success", func(t *testing.T) {
+			tlsConfig := &tls.Config{
+				ServerName: "dns.google",
+			}
+			fakeconn := &mocks.QUICEarlyConnection{}
+			systemdialer := quicDialerQUICGo{
+				QUICListener: &quicListenerStdlib{},
+				mockDialEarlyContext: func(ctx context.Context, pconn net.PacketConn,
+					remoteAddr net.Addr, host string, tlsConfig *tls.Config,
+					quicConfig *quic.Config) (quic.EarlyConnection, error) {
+					return fakeconn, nil
+				},
+			}
+			ctx := context.Background()
+			qconn, err := systemdialer.DialContext(
+				ctx, "8.8.8.8:443", tlsConfig, &quic.Config{})
+			if err != nil {
+				t.Fatal(err)
+			}
+			connOwner := qconn.(*quicConnectionOwnsConn)
+			if connOwner.EarlyConnection != fakeconn {
+				t.Fatal("invalid underlying conn")
+			}
+		})
 	})
 }
 
+func TestQUICDialerHandshakeCompleter(t *testing.T) {
+	t.Run("DialContext", func(t *testing.T) {
+		t.Run("in case of failure", func(t *testing.T) {
+			expected := errors.New("mocked error")
+			d := &quicDialerHandshakeCompleter{
+				Dialer: &mocks.QUICDialer{
+					MockDialContext: func(ctx context.Context, address string,
+						tlsConfig *tls.Config, quicConfig *quic.Config) (quic.EarlyConnection, error) {
+						return nil, expected
+					},
+				},
+			}
+			ctx := context.Background()
+			conn, err := d.DialContext(ctx, "8.8.8.8:443", &tls.Config{}, &quic.Config{})
+			if !errors.Is(err, expected) {
+				t.Fatal("unexpected err", err)
+			}
+			if conn != nil {
+				t.Fatal("expected nil conn")
+			}
+		})
+
+		t.Run("in case of context cancellation", func(t *testing.T) {
+			handshakeCtx, handshakeCancel := context.WithCancel(context.Background())
+			defer handshakeCancel()
+			ctx, cancel := context.WithCancel(context.Background())
+			var called bool
+			expected := &mocks.QUICEarlyConnection{
+				MockHandshakeComplete: func() context.Context {
+					cancel()
+					return handshakeCtx
+				},
+				MockCloseWithError: func(code quic.ApplicationErrorCode, reason string) error {
+					called = true
+					return nil
+				},
+			}
+			d := &quicDialerHandshakeCompleter{
+				Dialer: &mocks.QUICDialer{
+					MockDialContext: func(ctx context.Context, address string,
+						tlsConfig *tls.Config, quicConfig *quic.Config) (quic.EarlyConnection, error) {
+						return expected, nil
+					},
+				},
+			}
+			conn, err := d.DialContext(ctx, "8.8.8.8:443", &tls.Config{}, &quic.Config{})
+			if !errors.Is(err, context.Canceled) {
+				t.Fatal("unexpected err", err)
+			}
+			if conn != nil {
+				t.Fatal("expected nil conn")
+			}
+			if !called {
+				t.Fatal("not called")
+			}
+		})
+
+		t.Run("in case of success", func(t *testing.T) {
+			handshakeCtx, handshakeCancel := context.WithCancel(context.Background())
+			defer handshakeCancel()
+			expected := &mocks.QUICEarlyConnection{
+				MockHandshakeComplete: func() context.Context {
+					handshakeCancel()
+					return handshakeCtx
+				},
+			}
+			d := &quicDialerHandshakeCompleter{
+				Dialer: &mocks.QUICDialer{
+					MockDialContext: func(ctx context.Context, address string,
+						tlsConfig *tls.Config, quicConfig *quic.Config) (quic.EarlyConnection, error) {
+						return expected, nil
+					},
+				},
+			}
+			conn, err := d.DialContext(
+				context.Background(), "8.8.8.8:443", &tls.Config{}, &quic.Config{})
+			if err != nil {
+				t.Fatal(err)
+			}
+			if conn == nil {
+				t.Fatal("expected non-nil conn")
+			}
+		})
+	})
+
+	t.Run("CloseIdleConnections", func(t *testing.T) {
+		var forDialer bool
+		d := &quicDialerHandshakeCompleter{
+			Dialer: &mocks.QUICDialer{
+				MockCloseIdleConnections: func() {
+					forDialer = true
+				},
+			},
+		}
+		d.CloseIdleConnections()
+		if !forDialer {
+			t.Fatal("not called")
+		}
+	})
+}
+
+func TestQUICConnectionOwnsConn(t *testing.T) {
+	var (
+		quicClose bool
+		udpClose  bool
+	)
+	qconn := &mocks.QUICEarlyConnection{
+		MockCloseWithError: func(code quic.ApplicationErrorCode, reason string) error {
+			quicClose = true
+			return nil
+		},
+	}
+	pconn := &mocks.UDPLikeConn{
+		MockClose: func() error {
+			udpClose = true
+			return nil
+		},
+	}
+	conn := newQUICConnectionOwnsConn(qconn, pconn)
+	conn.CloseWithError(0, "")
+	if !quicClose {
+		t.Fatal("did not call qconn.CloseWithError")
+	}
+	if !udpClose {
+		t.Fatal("did not call pconn.Close")
+	}
+}
+
 func TestQUICDialerResolver(t *testing.T) {
 	t.Run("CloseIdleConnections", func(t *testing.T) {
 		var (
@@ -255,16 +486,16 @@ func TestQUICDialerResolver(t *testing.T) {
 		t.Run("with missing port", func(t *testing.T) {
 			tlsConfig := &tls.Config{}
 			dialer := &quicDialerResolver{
-				Resolver: NewResolverStdlib(log.Log),
+				Resolver: NewStdlibResolver(log.Log),
 				Dialer:   &quicDialerQUICGo{}}
-			sess, err := dialer.DialContext(
-				context.Background(), "udp", "www.google.com",
+			qconn, err := dialer.DialContext(
+				context.Background(), "www.google.com",
 				tlsConfig, &quic.Config{})
 			if err == nil || !strings.HasSuffix(err.Error(), "missing port in address") {
 				t.Fatal("not the error we expected")
 			}
-			if sess != nil {
-				t.Fatal("expected a nil sess here")
+			if qconn != nil {
+				t.Fatal("expected a nil connection here")
 			}
 		})
 
@@ -276,14 +507,14 @@ func TestQUICDialerResolver(t *testing.T) {
 					return nil, expected
 				},
 			}}
-			sess, err := dialer.DialContext(
-				context.Background(), "udp", "dns.google.com:853",
+			qconn, err := dialer.DialContext(
+				context.Background(), "dns.google.com:853",
 				tlsConfig, &quic.Config{})
 			if !errors.Is(err, expected) {
 				t.Fatal("not the error we expected")
 			}
-			if sess != nil {
-				t.Fatal("expected nil sess")
+			if qconn != nil {
+				t.Fatal("expected nil connection")
 			}
 		})
 
@@ -292,12 +523,12 @@ func TestQUICDialerResolver(t *testing.T) {
 			// to establish a connection leads to a failure
 			tlsConf := &tls.Config{}
 			dialer := &quicDialerResolver{
-				Resolver: NewResolverStdlib(log.Log),
+				Resolver: NewStdlibResolver(log.Log),
 				Dialer: &quicDialerQUICGo{
 					QUICListener: &quicListenerStdlib{},
 				}}
-			sess, err := dialer.DialContext(
-				context.Background(), "udp", "8.8.4.4:x",
+			qconn, err := dialer.DialContext(
+				context.Background(), "8.8.4.4:x",
 				tlsConf, &quic.Config{})
 			if err == nil {
 				t.Fatal("expected an error here")
@@ -305,8 +536,8 @@ func TestQUICDialerResolver(t *testing.T) {
 			if !strings.HasSuffix(err.Error(), "invalid syntax") {
 				t.Fatal("not the error we expected", err)
 			}
-			if sess != nil {
-				t.Fatal("expected nil sess")
+			if qconn != nil {
+				t.Fatal("expected nil connection")
 			}
 		})
 
@@ -315,22 +546,22 @@ func TestQUICDialerResolver(t *testing.T) {
 			var gotTLSConfig *tls.Config
 			tlsConfig := &tls.Config{}
 			dialer := &quicDialerResolver{
-				Resolver: NewResolverStdlib(log.Log),
+				Resolver: NewStdlibResolver(log.Log),
 				Dialer: &mocks.QUICDialer{
-					MockDialContext: func(ctx context.Context, network, address string,
-						tlsConfig *tls.Config, quicConfig *quic.Config) (quic.EarlySession, error) {
+					MockDialContext: func(ctx context.Context, address string,
+						tlsConfig *tls.Config, quicConfig *quic.Config) (quic.EarlyConnection, error) {
 						gotTLSConfig = tlsConfig
 						return nil, expected
 					},
 				}}
-			sess, err := dialer.DialContext(
-				context.Background(), "udp", "8.8.4.4:443",
+			qconn, err := dialer.DialContext(
+				context.Background(), "8.8.4.4:443",
 				tlsConfig, &quic.Config{})
 			if !errors.Is(err, expected) {
 				t.Fatal("not the error we expected", err)
 			}
-			if sess != nil {
-				t.Fatal("expected nil session here")
+			if qconn != nil {
+				t.Fatal("expected nil connection here")
 			}
 			if tlsConfig.ServerName != "" {
 				t.Fatal("should not have changed tlsConfig.ServerName")
@@ -339,6 +570,27 @@ func TestQUICDialerResolver(t *testing.T) {
 				t.Fatal("gotTLSConfig.ServerName has not been set")
 			}
 		})
+
+		t.Run("on success", func(t *testing.T) {
+			expectedQConn := &mocks.QUICEarlyConnection{}
+			dialer := &quicDialerResolver{
+				Resolver: NewStdlibResolver(log.Log),
+				Dialer: &mocks.QUICDialer{
+					MockDialContext: func(ctx context.Context, address string,
+						tlsConfig *tls.Config, quicConfig *quic.Config) (quic.EarlyConnection, error) {
+						return expectedQConn, nil
+					},
+				}}
+			qconn, err := dialer.DialContext(
+				context.Background(), "8.8.4.4:443",
+				&tls.Config{}, &quic.Config{})
+			if err != nil {
+				t.Fatal(err)
+			}
+			if qconn != expectedQConn {
+				t.Fatal("unexpected underlying qconn")
+			}
+		})
 	})
 
 	t.Run("lookup host with address", func(t *testing.T) {
@@ -385,10 +637,10 @@ func TestQUICLoggerDialer(t *testing.T) {
 			}
 			d := &quicDialerLogger{
 				Dialer: &mocks.QUICDialer{
-					MockDialContext: func(ctx context.Context, network string,
+					MockDialContext: func(ctx context.Context,
 						address string, tlsConfig *tls.Config,
-						quicConfig *quic.Config) (quic.EarlySession, error) {
-						return &mocks.QUICEarlySession{
+						quicConfig *quic.Config) (quic.EarlyConnection, error) {
+						return &mocks.QUICEarlyConnection{
 							MockCloseWithError: func(
 								code quic.ApplicationErrorCode, reason string) error {
 								return nil
@@ -401,11 +653,11 @@ func TestQUICLoggerDialer(t *testing.T) {
 			ctx := context.Background()
 			tlsConfig := &tls.Config{}
 			quicConfig := &quic.Config{}
-			sess, err := d.DialContext(ctx, "udp", "8.8.8.8:443", tlsConfig, quicConfig)
+			qconn, err := d.DialContext(ctx, "8.8.8.8:443", tlsConfig, quicConfig)
 			if err != nil {
 				t.Fatal(err)
 			}
-			if err := sess.CloseWithError(0, ""); err != nil {
+			if err := qconn.CloseWithError(0, ""); err != nil {
 				t.Fatal(err)
 			}
 			if called != 2 {
@@ -423,9 +675,9 @@ func TestQUICLoggerDialer(t *testing.T) {
 			expected := errors.New("mocked error")
 			d := &quicDialerLogger{
 				Dialer: &mocks.QUICDialer{
-					MockDialContext: func(ctx context.Context, network string,
+					MockDialContext: func(ctx context.Context,
 						address string, tlsConfig *tls.Config,
-						quicConfig *quic.Config) (quic.EarlySession, error) {
+						quicConfig *quic.Config) (quic.EarlyConnection, error) {
 						return nil, expected
 					},
 				},
@@ -434,12 +686,12 @@ func TestQUICLoggerDialer(t *testing.T) {
 			ctx := context.Background()
 			tlsConfig := &tls.Config{}
 			quicConfig := &quic.Config{}
-			sess, err := d.DialContext(ctx, "udp", "8.8.8.8:443", tlsConfig, quicConfig)
+			qconn, err := d.DialContext(ctx, "8.8.8.8:443", tlsConfig, quicConfig)
 			if !errors.Is(err, expected) {
 				t.Fatal("not the error we expected", err)
 			}
-			if sess != nil {
-				t.Fatal("expected nil session")
+			if qconn != nil {
+				t.Fatal("expected nil connection")
 			}
 			if called != 2 {
 				t.Fatal("invalid number of calls")
@@ -449,24 +701,24 @@ func TestQUICLoggerDialer(t *testing.T) {
 }
 
 func TestNewSingleUseQUICDialer(t *testing.T) {
-	sess := &mocks.QUICEarlySession{}
-	qd := NewSingleUseQUICDialer(sess)
+	qconn := &mocks.QUICEarlyConnection{}
+	qd := NewSingleUseQUICDialer(qconn)
 	defer qd.CloseIdleConnections()
-	outsess, err := qd.DialContext(
-		context.Background(), "", "", &tls.Config{}, &quic.Config{})
+	outconn, err := qd.DialContext(
+		context.Background(), "", &tls.Config{}, &quic.Config{})
 	if err != nil {
 		t.Fatal(err)
 	}
-	if sess != outsess {
-		t.Fatal("invalid outsess")
+	if qconn != outconn {
+		t.Fatal("invalid outconn")
 	}
 	for i := 0; i < 4; i++ {
-		outsess, err = qd.DialContext(
-			context.Background(), "", "", &tls.Config{}, &quic.Config{})
+		outconn, err = qd.DialContext(
+			context.Background(), "", &tls.Config{}, &quic.Config{})
 		if !errors.Is(err, ErrNoConnReuse) {
 			t.Fatal("not the error we expected", err)
 		}
-		if outsess != nil {
+		if outconn != nil {
 			t.Fatal("expected nil outconn here")
 		}
 	}
@@ -649,21 +901,21 @@ func TestQUICDialerErrWrapper(t *testing.T) {
 
 	t.Run("DialContext", func(t *testing.T) {
 		t.Run("on success", func(t *testing.T) {
-			expectedSess := &mocks.QUICEarlySession{}
+			expectedConn := &mocks.QUICEarlyConnection{}
 			d := &quicDialerErrWrapper{
 				QUICDialer: &mocks.QUICDialer{
-					MockDialContext: func(ctx context.Context, network, address string, tlsConfig *tls.Config, quicConfig *quic.Config) (quic.EarlySession, error) {
-						return expectedSess, nil
+					MockDialContext: func(ctx context.Context, address string, tlsConfig *tls.Config, quicConfig *quic.Config) (quic.EarlyConnection, error) {
+						return expectedConn, nil
 					},
 				},
 			}
 			ctx := context.Background()
-			sess, err := d.DialContext(ctx, "", "", &tls.Config{}, &quic.Config{})
+			qconn, err := d.DialContext(ctx, "", &tls.Config{}, &quic.Config{})
 			if err != nil {
 				t.Fatal(err)
 			}
-			if sess != expectedSess {
-				t.Fatal("unexpected sess")
+			if qconn != expectedConn {
+				t.Fatal("unexpected connection")
 			}
 		})
 
@@ -671,18 +923,18 @@ func TestQUICDialerErrWrapper(t *testing.T) {
 			expectedErr := io.EOF
 			d := &quicDialerErrWrapper{
 				QUICDialer: &mocks.QUICDialer{
-					MockDialContext: func(ctx context.Context, network, address string, tlsConfig *tls.Config, quicConfig *quic.Config) (quic.EarlySession, error) {
+					MockDialContext: func(ctx context.Context, address string, tlsConfig *tls.Config, quicConfig *quic.Config) (quic.EarlyConnection, error) {
 						return nil, expectedErr
 					},
 				},
 			}
 			ctx := context.Background()
-			sess, err := d.DialContext(ctx, "", "", &tls.Config{}, &quic.Config{})
+			qconn, err := d.DialContext(ctx, "", &tls.Config{}, &quic.Config{})
 			if err == nil || err.Error() != FailureEOFError {
 				t.Fatal("unexpected err", err)
 			}
-			if sess != nil {
-				t.Fatal("unexpected sess")
+			if qconn != nil {
+				t.Fatal("unexpected connection")
 			}
 		})
 	})
