@@ -30,6 +30,9 @@ func TestMeasurementSubmissionFailure(t *testing.T) {
 }
 
 func TestTaskRunnerRun(t *testing.T) {
+	if testing.Short() {
+		t.Skip("skip test in short mode")
+	}
 
 	// newRunnerForTesting is a factory for creating a new
 	// runner that wraps newRunner and also sets a specific
@@ -201,8 +204,8 @@ func TestTaskRunnerRun(t *testing.T) {
 			},
 			MockableSetCallbacks: func(callbacks model.ExperimentCallbacks) {
 			},
-			MockableInputPolicy: func() engine.InputPolicy {
-				return engine.InputNone
+			MockableInputPolicy: func() model.InputPolicy {
+				return model.InputNone
 			},
 			MockableInterruptible: func() bool {
 				return false
@@ -307,8 +310,8 @@ func TestTaskRunnerRun(t *testing.T) {
 	t.Run("with missing input and InputOrQueryBackend policy", func(t *testing.T) {
 		runner, emitter := newRunnerForTesting()
 		fake := fakeSuccessfulRun()
-		fake.MockableInputPolicy = func() engine.InputPolicy {
-			return engine.InputOrQueryBackend
+		fake.MockableInputPolicy = func() model.InputPolicy {
+			return model.InputOrQueryBackend
 		}
 		runner.sessionBuilder = fake
 		events := runAndCollect(runner, emitter)
@@ -328,8 +331,8 @@ func TestTaskRunnerRun(t *testing.T) {
 	t.Run("with missing input and InputStrictlyRequired policy", func(t *testing.T) {
 		runner, emitter := newRunnerForTesting()
 		fake := fakeSuccessfulRun()
-		fake.MockableInputPolicy = func() engine.InputPolicy {
-			return engine.InputStrictlyRequired
+		fake.MockableInputPolicy = func() model.InputPolicy {
+			return model.InputStrictlyRequired
 		}
 		runner.sessionBuilder = fake
 		events := runAndCollect(runner, emitter)
@@ -352,8 +355,8 @@ func TestTaskRunnerRun(t *testing.T) {
 			runner, emitter := newRunnerForTesting()
 			runner.settings.Name = "Antani" // no input for this experiment
 			fake := fakeSuccessfulRun()
-			fake.MockableInputPolicy = func() engine.InputPolicy {
-				return engine.InputOrStaticDefault
+			fake.MockableInputPolicy = func() model.InputPolicy {
+				return model.InputOrStaticDefault
 			}
 			runner.sessionBuilder = fake
 			events := runAndCollect(runner, emitter)
@@ -374,8 +377,8 @@ func TestTaskRunnerRun(t *testing.T) {
 		runner, emitter := newRunnerForTesting()
 		runner.settings.Inputs = append(runner.settings.Inputs, "https://x.org/")
 		fake := fakeSuccessfulRun()
-		fake.MockableInputPolicy = func() engine.InputPolicy {
-			return engine.InputNone
+		fake.MockableInputPolicy = func() model.InputPolicy {
+			return model.InputNone
 		}
 		runner.sessionBuilder = fake
 		events := runAndCollect(runner, emitter)
@@ -416,8 +419,8 @@ func TestTaskRunnerRun(t *testing.T) {
 	t.Run("with success and InputNone policy", func(t *testing.T) {
 		runner, emitter := newRunnerForTesting()
 		fake := fakeSuccessfulRun()
-		fake.MockableInputPolicy = func() engine.InputPolicy {
-			return engine.InputNone
+		fake.MockableInputPolicy = func() model.InputPolicy {
+			return model.InputNone
 		}
 		runner.sessionBuilder = fake
 		events := runAndCollect(runner, emitter)
@@ -442,8 +445,8 @@ func TestTaskRunnerRun(t *testing.T) {
 	t.Run("with measurement failure and InputNone policy", func(t *testing.T) {
 		runner, emitter := newRunnerForTesting()
 		fake := fakeSuccessfulRun()
-		fake.MockableInputPolicy = func() engine.InputPolicy {
-			return engine.InputNone
+		fake.MockableInputPolicy = func() model.InputPolicy {
+			return model.InputNone
 		}
 		fake.MockableMeasureWithContext = func(ctx context.Context, input string) (measurement *model.Measurement, err error) {
 			return nil, errors.New("preconditions error")
@@ -466,12 +469,45 @@ func TestTaskRunnerRun(t *testing.T) {
 		assertReducedEventsLike(t, expect, reduced)
 	})
 
+	t.Run("with measurement failure and annotations", func(t *testing.T) {
+		// See https://github.com/ooni/probe/issues/2173. We want to be sure that
+		// we are not crashing when the measurement fails and there are annotations,
+		// which is what was happening in the above referenced issue.
+		runner, emitter := newRunnerForTesting()
+		fake := fakeSuccessfulRun()
+		fake.MockableInputPolicy = func() model.InputPolicy {
+			return model.InputNone
+		}
+		fake.MockableMeasureWithContext = func(ctx context.Context, input string) (measurement *model.Measurement, err error) {
+			return nil, errors.New("preconditions error")
+		}
+		runner.sessionBuilder = fake
+		runner.settings.Annotations = map[string]string{
+			"architecture": "arm64",
+		}
+		events := runAndCollect(runner, emitter)
+		reduced := reduceEventsKeysIgnoreLog(events)
+		expect := []eventKeyCount{
+			{Key: eventTypeStatusQueued, Count: 1},
+			{Key: eventTypeStatusStarted, Count: 1},
+			{Key: eventTypeStatusProgress, Count: 3},
+			{Key: eventTypeStatusGeoIPLookup, Count: 1},
+			{Key: eventTypeStatusResolverLookup, Count: 1},
+			{Key: eventTypeStatusProgress, Count: 1},
+			{Key: eventTypeStatusReportCreate, Count: 1},
+			{Key: eventTypeStatusMeasurementStart, Count: 1},
+			{Key: eventTypeFailureMeasurement, Count: 1},
+			{Key: eventTypeStatusEnd, Count: 1},
+		}
+		assertReducedEventsLike(t, expect, reduced)
+	})
+
 	t.Run("with success and InputStrictlyRequired", func(t *testing.T) {
 		runner, emitter := newRunnerForTesting()
 		runner.settings.Inputs = []string{"a", "b", "c", "d"}
 		fake := fakeSuccessfulRun()
-		fake.MockableInputPolicy = func() engine.InputPolicy {
-			return engine.InputStrictlyRequired
+		fake.MockableInputPolicy = func() model.InputPolicy {
+			return model.InputStrictlyRequired
 		}
 		runner.sessionBuilder = fake
 		events := runAndCollect(runner, emitter)
@@ -518,8 +554,8 @@ func TestTaskRunnerRun(t *testing.T) {
 		runner, emitter := newRunnerForTesting()
 		runner.settings.Inputs = []string{"a", "b", "c", "d"}
 		fake := fakeSuccessfulRun()
-		fake.MockableInputPolicy = func() engine.InputPolicy {
-			return engine.InputOptional
+		fake.MockableInputPolicy = func() model.InputPolicy {
+			return model.InputOptional
 		}
 		runner.sessionBuilder = fake
 		events := runAndCollect(runner, emitter)
@@ -565,8 +601,8 @@ func TestTaskRunnerRun(t *testing.T) {
 	t.Run("with success and InputOptional and no input", func(t *testing.T) {
 		runner, emitter := newRunnerForTesting()
 		fake := fakeSuccessfulRun()
-		fake.MockableInputPolicy = func() engine.InputPolicy {
-			return engine.InputOptional
+		fake.MockableInputPolicy = func() model.InputPolicy {
+			return model.InputOptional
 		}
 		runner.sessionBuilder = fake
 		events := runAndCollect(runner, emitter)
@@ -595,8 +631,8 @@ func TestTaskRunnerRun(t *testing.T) {
 		runner, emitter := newRunnerForTesting()
 		runner.settings.Name = experimentName
 		fake := fakeSuccessfulRun()
-		fake.MockableInputPolicy = func() engine.InputPolicy {
-			return engine.InputOrStaticDefault
+		fake.MockableInputPolicy = func() model.InputPolicy {
+			return model.InputOrStaticDefault
 		}
 		runner.sessionBuilder = fake
 		events := runAndCollect(runner, emitter)
@@ -631,8 +667,8 @@ func TestTaskRunnerRun(t *testing.T) {
 		runner.settings.Inputs = []string{"a", "b", "c", "d"}
 		runner.settings.Options.MaxRuntime = 2
 		fake := fakeSuccessfulRun()
-		fake.MockableInputPolicy = func() engine.InputPolicy {
-			return engine.InputStrictlyRequired
+		fake.MockableInputPolicy = func() model.InputPolicy {
+			return model.InputStrictlyRequired
 		}
 		fake.MockableMeasureWithContext = func(ctx context.Context, input string) (measurement *model.Measurement, err error) {
 			time.Sleep(1 * time.Second)
@@ -672,8 +708,8 @@ func TestTaskRunnerRun(t *testing.T) {
 		runner.settings.Inputs = []string{"a", "b", "c", "d"}
 		runner.settings.Options.MaxRuntime = 2
 		fake := fakeSuccessfulRun()
-		fake.MockableInputPolicy = func() engine.InputPolicy {
-			return engine.InputStrictlyRequired
+		fake.MockableInputPolicy = func() model.InputPolicy {
+			return model.InputStrictlyRequired
 		}
 		fake.MockableInterruptible = func() bool {
 			return true
@@ -707,8 +743,8 @@ func TestTaskRunnerRun(t *testing.T) {
 		runner, emitter := newRunnerForTesting()
 		runner.settings.Inputs = []string{"a"}
 		fake := fakeSuccessfulRun()
-		fake.MockableInputPolicy = func() engine.InputPolicy {
-			return engine.InputStrictlyRequired
+		fake.MockableInputPolicy = func() model.InputPolicy {
+			return model.InputStrictlyRequired
 		}
 		fake.MockableSubmitAndUpdateMeasurementContext = func(ctx context.Context, measurement *model.Measurement) error {
 			return errors.New("cannot submit")
